--- a/inc/FrameTable.h Tue May 11 16:42:02 2010 +0300
+++ b/inc/FrameTable.h Tue May 25 13:16:00 2010 +0300
@@ -113,7 +113,6 @@
TUint iAvgBitrate;
TUint iOffset;
TUint iTimeRefMs;
- TUint iBufCnt;
TUint iPosEventMs;
TUint iPlayWindowEndPosEventMs;
TInt iIntervalRef;
--- a/mmfenh/advancedaudiocontroller/audiocontrollerpluginsvariant/3gpaudioplaycontroller/Src/3GPAudioPlayControllerRecognizer.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmfenh/advancedaudiocontroller/audiocontrollerpluginsvariant/3gpaudioplaycontroller/Src/3GPAudioPlayControllerRecognizer.cpp Tue May 25 13:16:00 2010 +0300
@@ -30,6 +30,7 @@
_LIT(KDot, ".");
_LIT(KDot3gp, ".3gp");
_LIT(KDot3ga, ".3ga");
+_LIT(KDot3gpp, ".3gpp");
_LIT8(K3gpAudioMimeType, "audio/3gpp");
_LIT8(K3gpVideoMimeType, "video/3gpp");
@@ -202,7 +203,14 @@
}
}
- TPtrC ext(aName.Right(KExtLength));
+ // TPtrC ext(aName.Right(KExtLength));
+ TInt num=aName.LocateReverse('.');
+ if(num < 0)
+ {
+ num = 0;
+ }
+ TPtrC ext(aName.Right(aName.Length()-num));
+
DP0(_L("C3GPAudioPlayControllerRecognizer::DoRecognizeL: Extension:"));
#ifdef _DEBUG
RDebug::RawPrint(ext);
@@ -211,7 +219,7 @@
if ( (ext.CompareF(KDot3gp) == 0) || (ext.CompareF(KDotMp4) == 0) ||
(ext.CompareF(KDotM4a) == 0) || (ext.CompareF(KDot3g2) == 0) ||
- (ext.CompareF(KDot3ga) == 0) || headerMatch)
+ (ext.CompareF(KDot3ga) == 0) || (ext.CompareF(KDot3gpp) == 0) || headerMatch)
{
RFile* fileHandle= NULL;
TRAPD(handleErr, fileHandle = FilePassedByHandleL());
@@ -277,7 +285,7 @@
(header.FindF(K3gs6Header) == 0) ||
(header.FindF(KMmp4Header) == 0) ||
(ext.CompareF(KDot3gp) == 0) ||
- (ext.CompareF(KDot3ga) == 0) )
+ (ext.CompareF(KDot3ga) == 0)||(ext.CompareF(KDot3gpp) == 0) )
{
iDataType = TDataType(K3gpAudioMimeType);
iConfidence = ECertain;
@@ -308,7 +316,7 @@
(header.FindF(K3gr6Header) == 0) ||
(header.FindF(K3gs6Header) == 0) ||
(header.FindF(KMmp4Header) == 0) ||
- (ext.CompareF(KDot3gp) == 0) )
+ (ext.CompareF(KDot3gp) == 0) || (ext.CompareF(KDot3gpp) == 0))
{
iDataType = TDataType(K3gpVideoMimeType);
iConfidence = ECertain;
--- a/mmfenh/advancedaudiocontroller/audiocontrollerpluginsvariant/3gpaudioplaycontroller/Src/3GPAudioPlayControllerResource.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmfenh/advancedaudiocontroller/audiocontrollerpluginsvariant/3gpaudioplaycontroller/Src/3GPAudioPlayControllerResource.cpp Tue May 25 13:16:00 2010 +0300
@@ -18,7 +18,7 @@
// INCLUDE FILES
-#include <3GPAudioPlayControllerResource.rsg>
+#include <3gpaudioplaycontrollerresource.rsg>
#include "3GPAudioPlayControllerResource.h"
#include <data_caging_path_literals.hrh>
--- a/mmfenh/advancedaudiocontroller/audiocontrollerpluginsvariant/3gpaudiorecordcontroller/Src/3GPAudioRecordControllerResource.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmfenh/advancedaudiocontroller/audiocontrollerpluginsvariant/3gpaudiorecordcontroller/Src/3GPAudioRecordControllerResource.cpp Tue May 25 13:16:00 2010 +0300
@@ -18,7 +18,7 @@
// INCLUDE FILES
-#include <3GPAudioRecordControllerResource.rsg>
+#include <3gpaudiorecordcontrollerresource.rsg>
#include "3GPAudioRecordControllerResource.h"
#include <data_caging_path_literals.hrh>
--- a/mmfenh/advancedaudiocontroller/audiocontrollerpluginsvariant/AdvancedAudioController/Inc/AdvancedAudioInput.h Tue May 11 16:42:02 2010 +0300
+++ b/mmfenh/advancedaudiocontroller/audiocontrollerpluginsvariant/AdvancedAudioController/Inc/AdvancedAudioInput.h Tue May 25 13:16:00 2010 +0300
@@ -30,7 +30,7 @@
//#include <MmfControllerFrameworkBase.h>
//#include <MmfControllerFramework.h>
//#include <MmfBase.h>
-//#include <MmfPanicCodes.h>
+//#include <mmfpaniccodes.h>
#include "AdvancedAudioEncoder.h"
// CLASS DECLARATION
--- a/mmfenh/advancedaudiocontroller/audiocontrollerpluginsvariant/AdvancedAudioController/Inc/AdvancedAudioOutput.h Tue May 11 16:42:02 2010 +0300
+++ b/mmfenh/advancedaudiocontroller/audiocontrollerpluginsvariant/AdvancedAudioController/Inc/AdvancedAudioOutput.h Tue May 25 13:16:00 2010 +0300
@@ -30,7 +30,7 @@
//#include <MmfControllerFrameworkBase.h>
//#include <MmfControllerFramework.h>
//#include <MmfBase.h>
-//#include <MmfPanicCodes.h>
+//#include <mmfpaniccodes.h>
#include "AdvancedAudioDecoder.h"
#include "DataSourceAdapter.h"
--- a/mmfenh/advancedaudiocontroller/audiocontrollerpluginsvariant/AdvancedAudioController/Inc/AdvancedAudioPlayController.h Tue May 11 16:42:02 2010 +0300
+++ b/mmfenh/advancedaudiocontroller/audiocontrollerpluginsvariant/AdvancedAudioController/Inc/AdvancedAudioPlayController.h Tue May 25 13:16:00 2010 +0300
@@ -832,7 +832,7 @@
// sets the repeat count and trailing silence timer value supplied by the client
TInt DoSetRepeats(TInt aRepeatNumberOfTimes, const TTimeIntervalMicroSeconds& aTrailingSilence);
// handles the loop play of seekable and non-seekable sources
- void DoRepeat();
+ void DoRepeatL();
TBool IsLoopPlayEnabled() const;
public: // Functions from base classes (MTrailingSilenceObserver)
--- a/mmfenh/advancedaudiocontroller/audiocontrollerpluginsvariant/AdvancedAudioController/Src/AdvancedAudioRecordController.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmfenh/advancedaudiocontroller/audiocontrollerpluginsvariant/AdvancedAudioController/Src/AdvancedAudioRecordController.cpp Tue May 25 13:16:00 2010 +0300
@@ -1019,6 +1019,18 @@
EXPORT_C void CAdvancedAudioRecordController::SendEvent(
const TMMFEvent& aEvent )
{
+#ifdef _DEBUG
+ RDebug::Print(_L("CAdvancedAudioRecordController::SendEvent[%d] this[%x]"), aEvent.iErrorCode, this);
+#endif
+ // fix for DALM-853QJX, handling preemption use case during recording, this handles only preemption errors and other errors are ignored
+ // MMFDevSound throws the following error codes incase of any preemption events
+ // (DevSound instance has been thrown-off or initial request has been rejected)
+ if ( (aEvent.iErrorCode == KErrAccessDenied) || (aEvent.iErrorCode == KErrInUse) || (aEvent.iErrorCode == KErrDied) )
+ {
+ // this might be a DevSound Preemption
+ iState = EStopping;
+ TRAP_IGNORE(DoStopL());
+ }
SendEventToClient(aEvent);
}
--- a/mmfenh/advancedaudiocontroller/audiocontrollerpluginsvariant/aacaudioplaycontroller/Src/AACAudioPlayControllerHwDecoder.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmfenh/advancedaudiocontroller/audiocontrollerpluginsvariant/aacaudioplaycontroller/Src/AACAudioPlayControllerHwDecoder.cpp Tue May 25 13:16:00 2010 +0300
@@ -23,7 +23,7 @@
#include "DebugMacros.h"
#include <Mmfcodec.h>
-#include <MmfPanicCodes.h>
+#include <mmfpaniccodes.h>
// New eAAC+ custom interface is used only when using DSP decoder and
// the eAAC+ feature is turned on.
--- a/mmfenh/advancedaudiocontroller/audiocontrollerpluginsvariant/aacaudioplaycontroller/Src/AACAudioPlayControllerResource.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmfenh/advancedaudiocontroller/audiocontrollerpluginsvariant/aacaudioplaycontroller/Src/AACAudioPlayControllerResource.cpp Tue May 25 13:16:00 2010 +0300
@@ -18,7 +18,7 @@
// INCLUDE FILES
#include "AACAudioPlayControllerResource.h"
-#include <AACAudioPlayControllerResource.rsg>
+#include <aacaudioplaycontrollerresource.rsg>
#include <data_caging_path_literals.hrh>
// LOCAL CONSTANTS AND MACROS
--- a/mmfenh/advancedaudiocontroller/audiocontrollerpluginsvariant/amraudioplaycontroller/Src/AMRAudioPlayControllerHwDecoder.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmfenh/advancedaudiocontroller/audiocontrollerpluginsvariant/amraudioplaycontroller/Src/AMRAudioPlayControllerHwDecoder.cpp Tue May 25 13:16:00 2010 +0300
@@ -22,7 +22,7 @@
#include "AMRAudioPlayControllerDecoder.h"
#include "DebugMacros.h"
//#include <AmrDecHwDeviceTICIM.h>
-#include <MmfPanicCodes.h>
+#include <mmfpaniccodes.h>
// The size of AMR header, header must include bits for determining frame length
const TInt KAmrFrameHeaderSize1 = 1;
--- a/mmfenh/advancedaudiocontroller/audiocontrollerpluginsvariant/amraudioplaycontroller/Src/AMRAudioPlayControllerResource.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmfenh/advancedaudiocontroller/audiocontrollerpluginsvariant/amraudioplaycontroller/Src/AMRAudioPlayControllerResource.cpp Tue May 25 13:16:00 2010 +0300
@@ -18,7 +18,7 @@
// INCLUDE FILES
-#include <AMRAudioPlayControllerResource.rsg>
+#include <amraudioplaycontrollerresource.rsg>
#include "AMRAudioPlayControllerResource.h"
#include "DebugMacros.h"
#include <data_caging_path_literals.hrh>
--- a/mmfenh/advancedaudiocontroller/audiocontrollerpluginsvariant/amraudiorecordcontroller/Src/AMRAudioRecordControllerHwEncoder.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmfenh/advancedaudiocontroller/audiocontrollerpluginsvariant/amraudiorecordcontroller/Src/AMRAudioRecordControllerHwEncoder.cpp Tue May 25 13:16:00 2010 +0300
@@ -20,7 +20,7 @@
// INCLUDE FILES
#include "AMRAudioRecordControllerEncoder.h"
-#include <MmfPanicCodes.h>
+#include <mmfpaniccodes.h>
#include <SpeechEncoderConfig.h> // Custom Interface for Speech Encoder Configuration
// AMR Bit Rate constant
--- a/mmfenh/advancedaudiocontroller/audiocontrollerpluginsvariant/amraudiorecordcontroller/Src/AMRAudioRecordControllerResource.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmfenh/advancedaudiocontroller/audiocontrollerpluginsvariant/amraudiorecordcontroller/Src/AMRAudioRecordControllerResource.cpp Tue May 25 13:16:00 2010 +0300
@@ -18,7 +18,7 @@
// INCLUDE FILES
-#include <AMRAudioRecordControllerResource.rsg>
+#include <amraudiorecordcontrollerresource.rsg>
#include "AMRAudioRecordControllerResource.h"
#include <data_caging_path_literals.hrh>
--- a/mmfenh/advancedaudiocontroller/audiocontrollerpluginsvariant/awbaudioplaycontroller/Src/AWBAudioPlayControllerHwDecoder.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmfenh/advancedaudiocontroller/audiocontrollerpluginsvariant/awbaudioplaycontroller/Src/AWBAudioPlayControllerHwDecoder.cpp Tue May 25 13:16:00 2010 +0300
@@ -23,7 +23,7 @@
#include "DebugMacros.h"
//#include <AmrWbDecHwDeviceTICIM.h>
-#include <MmfPanicCodes.h>
+#include <mmfpaniccodes.h>
const TInt KAwbFrameHeaderSize1 = 1;
--- a/mmfenh/advancedaudiocontroller/audiocontrollerpluginsvariant/awbaudioplaycontroller/Src/AWBAudioPlayControllerResource.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmfenh/advancedaudiocontroller/audiocontrollerpluginsvariant/awbaudioplaycontroller/Src/AWBAudioPlayControllerResource.cpp Tue May 25 13:16:00 2010 +0300
@@ -18,7 +18,7 @@
// INCLUDE FILES
-#include <AWBAudioPlayControllerResource.rsg>
+#include <awbaudioplaycontrollerresource.rsg>
#include "AWBAudioPlayControllerResource.h"
#include <data_caging_path_literals.hrh>
#include "DebugMacros.h"
--- a/mmfenh/advancedaudiocontroller/audiocontrollerpluginsvariant/mp3audioplaycontroller/Src/MP3AudioPlayControllerHwDecoder.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmfenh/advancedaudiocontroller/audiocontrollerpluginsvariant/mp3audioplaycontroller/Src/MP3AudioPlayControllerHwDecoder.cpp Tue May 25 13:16:00 2010 +0300
@@ -21,7 +21,7 @@
// INCLUDE FILES
#include "MP3AudioPlayControllerDecoder.h"
#include "DebugMacros.h"
-#include <MmfPanicCodes.h>
+#include <mmfpaniccodes.h>
#include <Mmfcodec.h>
const TUint KRawMp3MaxFrameSize = 1441;
--- a/mmfenh/advancedaudiocontroller/audiocontrollerpluginsvariant/mp3audioplaycontroller/Src/MP3AudioPlayControllerResource.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmfenh/advancedaudiocontroller/audiocontrollerpluginsvariant/mp3audioplaycontroller/Src/MP3AudioPlayControllerResource.cpp Tue May 25 13:16:00 2010 +0300
@@ -18,7 +18,7 @@
// INCLUDE FILES
-#include <MP3AudioPlayControllerResource.rsg>
+#include <mp3audioplaycontrollerresource.rsg>
#include "MP3AudioPlayControllerResource.h"
#include "DebugMacros.h"
--- a/mmfenh/advancedaudiocontroller/tsrc/advancedaudiocontrollertestmodule/AudioPlaybackTestModule/inc/SimpleSoundPlayer.h Tue May 11 16:42:02 2010 +0300
+++ b/mmfenh/advancedaudiocontroller/tsrc/advancedaudiocontrollertestmodule/AudioPlaybackTestModule/inc/SimpleSoundPlayer.h Tue May 25 13:16:00 2010 +0300
@@ -18,7 +18,7 @@
#ifndef __SOUND_PLAYER_H
#define __SOUND_PLAYER_H
-#include <MdaAudioSamplePlayer.h>
+#include <mdaaudiosampleplayer.h>
#include <StifTestModule.h>
#include "EventTarget.h"
#include "Parameters.h"
--- a/mmfenh/advancedaudiocontroller/tsrc/advancedaudiocontrollertestmodule/AudioPlaybackTestModule/src/MmfTsPlay.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmfenh/advancedaudiocontroller/tsrc/advancedaudiocontrollertestmodule/AudioPlaybackTestModule/src/MmfTsPlay.cpp Tue May 25 13:16:00 2010 +0300
@@ -372,7 +372,7 @@
TParsePtrC fp(aConfig);
iLogger->Log(_L("Opening configuration file [%S], case #%d"), &aConfig,
aCaseNumber);
- CStifParser *parser;
+ CStifParser *parser = NULL;
TRAPD(error, parser = CStifParser::NewL(fp.DriveAndPath() , fp.NameAndExt() ));
iLogger->Log(_L("CStifParser::NewL [%d] \n"), error);
if (error == KErrNone)
--- a/mmfenh/advancedaudiocontroller/tsrc/advancedaudiocontrollertestmodule/AudioPlaybackTestModule/src/MmfTsPlay_work.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmfenh/advancedaudiocontroller/tsrc/advancedaudiocontrollertestmodule/AudioPlaybackTestModule/src/MmfTsPlay_work.cpp Tue May 25 13:16:00 2010 +0300
@@ -428,7 +428,7 @@
{
TInt i;
TInt j=0;
- CMMFMetaDataEntry* metaDataPtr;
+ CMMFMetaDataEntry* metaDataPtr = NULL;
for( i = 0; i < aEntryCount; i++)
{
--- a/mmfenh/advancedaudiocontroller/tsrc/advancedaudiocontrollertestmodule/AudioToneTestModule/src/MmfTsTone_core.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmfenh/advancedaudiocontroller/tsrc/advancedaudiocontrollertestmodule/AudioToneTestModule/src/MmfTsTone_core.cpp Tue May 25 13:16:00 2010 +0300
@@ -1788,7 +1788,7 @@
CMediaEvent *ime = CMediaEvent::NewL(&iOutputPrinter,delay,0, player, reportParams);
CleanupStack::PushL(ime);
- TInt expectedVolume;
+ TInt expectedVolume = 0 ;
iOutputPrinter.Printf(_L("current volume before change:%d"),player->GetVolume());
RDebug::Print(_L("current volume before change:%d"),player->GetVolume());
switch(volumeLevel)
--- a/mmfenh/audiooutputcontrolutility/AudioOutputControlUtilityProxy/src/AudioOutputControlUtilityProxyImpl.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmfenh/audiooutputcontrolutility/AudioOutputControlUtilityProxy/src/AudioOutputControlUtilityProxyImpl.cpp Tue May 25 13:16:00 2010 +0300
@@ -167,6 +167,7 @@
CleanupStack::Pop(iAudioOutput);
else
CleanupStack::PopAndDestroy(iAudioOutput);
+ iAudioOutput = NULL;
}
return err;
}
@@ -253,9 +254,12 @@
{
//in case of EMC sources
CleanupStack::PopAndDestroy(iDRMConfigIntfc);
+ iDRMConfigIntfc = NULL;
}
CleanupStack::PopAndDestroy(iRestrictedAudioOutput);
CleanupStack::PopAndDestroy(iFactory);
+ iFactory = NULL;
+ iRestrictedAudioOutput = NULL;
}
return err;
--- a/mmmw_plat/telephony_multimedia_service_api/inc/tmsbuffer.h Tue May 11 16:42:02 2010 +0300
+++ b/mmmw_plat/telephony_multimedia_service_api/inc/tmsbuffer.h Tue May 25 13:16:00 2010 +0300
@@ -35,6 +35,11 @@
class TMSBuffer
{
public:
+ /*
+ * Destructor
+ */
+ virtual ~TMSBuffer() {}
+
/**
* Return buffer type.
*
@@ -42,7 +47,8 @@
* Type of the buffer object (TMS_BUFFER_MEMORY).
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
*
*/
virtual gint GetType(TMSBufferType& buftype) = 0;
@@ -56,7 +62,8 @@
* Time stamp in microseconds.
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
*
*/
virtual gint GetTimeStamp(guint64& ts) = 0;
@@ -70,7 +77,8 @@
* Time stamp in microseconds.
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
*
*/
virtual gint SetTimeStamp(const guint64 ts) = 0;
@@ -82,7 +90,8 @@
* Size of data in the buffer.
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
*
*/
virtual gint GetDataSize(guint& size) = 0;
@@ -94,7 +103,8 @@
* Size of data in the buffer.
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
*
*/
virtual gint SetDataSize(const guint size) = 0;
@@ -107,7 +117,8 @@
* Pointer to the data stored in the buffer.
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
*
*/
virtual gint GetDataPtr(guint8*& bufptr) = 0;
--- a/mmmw_plat/telephony_multimedia_service_api/inc/tmscall.h Tue May 11 16:42:02 2010 +0300
+++ b/mmmw_plat/telephony_multimedia_service_api/inc/tmscall.h Tue May 25 13:16:00 2010 +0300
@@ -92,7 +92,8 @@
* Context ID.
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
* TMS_RESULT_FATAL_ERROR if an error occured.
*
*/
@@ -108,7 +109,8 @@
* Created stream.
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
* TMS_RESULT_INSUFFICIENT_MEMORY if call creation failed due to
* insufficient memory.
* TMS_RESULT_STREAM_TYPE_NOT_SUPPORTED if stream type is not
@@ -117,7 +119,7 @@
* TMS_REASON_EMERGENCY_CALL_ONGOING if emergency call is active.
* TMS_REASON_PERMISSION_DENIED if permission is denied.
* TMS_RESULT_INVALID_ARGUMENT if strm is not set to NULL.
- * TMS_RESULT_ALREADY_EXIST if the same streamtype is created
+ * TMS_RESULT_ALREADY_EXIST if the same streamtype is created
* multiple times.
*
*/
@@ -130,7 +132,8 @@
* Stream to be deleted.
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
* TMS_RESULT_INVALID_ARGUMENT if the stream is not valid.
*/
IMPORT_C gint DeleteStream(TMSStream*& strm);
--- a/mmmw_plat/telephony_multimedia_service_api/inc/tmsclientsink.h Tue May 11 16:42:02 2010 +0300
+++ b/mmmw_plat/telephony_multimedia_service_api/inc/tmsclientsink.h Tue May 25 13:16:00 2010 +0300
@@ -72,7 +72,8 @@
* Any user data passed to the function.
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
* TMS_RESULT_ALREADY_EXIST if the obsrvr is already in the list.
*
*/
@@ -88,7 +89,8 @@
* The listener to be removed.
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
* TMS_RESULT_DOES_NOT_EXIST if obsrvr is not already in the list.
*
*/
@@ -120,7 +122,8 @@
* The type of sink object (TMS_SINK_CLIENT).
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
*
*/
IMPORT_C virtual gint GetType(TMSSinkType& sinktype);
--- a/mmmw_plat/telephony_multimedia_service_api/inc/tmsclientsource.h Tue May 11 16:42:02 2010 +0300
+++ b/mmmw_plat/telephony_multimedia_service_api/inc/tmsclientsource.h Tue May 25 13:16:00 2010 +0300
@@ -68,7 +68,8 @@
* Any user data passed to the function.
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
* TMS_RESULT_ALREADY_EXIST if the obsrvr is already in the list.
*
*/
@@ -140,7 +141,8 @@
* Toggles buffer enqueuing ON and OFF.
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
*
*/
IMPORT_C gint SetEnqueueMode(const gboolean enable);
@@ -167,7 +169,8 @@
* Has no effect in the PULL mode.
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
*
*/
IMPORT_C gint Flush();
@@ -185,7 +188,8 @@
* TMS_STREAM_MIC
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
*
*/
IMPORT_C virtual gint GetType(TMSSourceType& sourcetype);
--- a/mmmw_plat/telephony_multimedia_service_api/inc/tmsclientsourceobsrvr.h Tue May 11 16:42:02 2010 +0300
+++ b/mmmw_plat/telephony_multimedia_service_api/inc/tmsclientsourceobsrvr.h Tue May 25 13:16:00 2010 +0300
@@ -20,7 +20,7 @@
#define TMS_CLIENT_SOURCE_OBSRVR_H
// Include files
-#include <glib.h>
+#include <tms.h>
namespace TMS {
--- a/mmmw_plat/telephony_multimedia_service_api/inc/tmsformat.h Tue May 11 16:42:02 2010 +0300
+++ b/mmmw_plat/telephony_multimedia_service_api/inc/tmsformat.h Tue May 25 13:16:00 2010 +0300
@@ -64,7 +64,8 @@
* The typedef std::vector<guint> BitRateVector; list of codecs.
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
* TMS_RESULT_FEATURE_NOT_SUPPORTED if this method is not implemented
* by the adaptation.
*
@@ -80,7 +81,8 @@
* Bitrate to be set for the encoder.
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
* TMS_RESULT_INVALID_ARGUMENT if requested bitrate is invalid.
* TMS_RESULT_FEATURE_NOT_SUPPORTED if this method is not implemented
* by the adaptation.
@@ -97,7 +99,8 @@
* Current bitrate.
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
* TMS_RESULT_FEATURE_NOT_SUPPORTED if this method is not implemented
* by the adaptation.
*
@@ -111,7 +114,8 @@
* Type of the format object.
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
*
*/
IMPORT_C virtual gint GetType(TMSFormatType& fmttype);
--- a/mmmw_plat/telephony_multimedia_service_api/inc/tmsg711format.h Tue May 11 16:42:02 2010 +0300
+++ b/mmmw_plat/telephony_multimedia_service_api/inc/tmsg711format.h Tue May 25 13:16:00 2010 +0300
@@ -59,7 +59,8 @@
* Sets selected G.711 encoding or decoding mode.
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
* TMS_RESULT_INVALID_STATE if this method is used during active
* encoding or decoding operation.
* TMS_RESULT_FEATURE_NOT_SUPPORTED if this method is not implemented
@@ -82,7 +83,8 @@
* Returns current G.711 encoding or decoding mode.
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
*
*/
IMPORT_C gint GetMode(TMSG711CodecMode& mode);
@@ -98,7 +100,8 @@
* Sets CNG feature on or off.
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
* TMS_RESULT_INVALID_STATE if this method is used during active
* decoding operation.
* TMS_RESULT_FEATURE_NOT_SUPPORTED if this method is not implemented
@@ -117,7 +120,7 @@
* Current CNG setting of the decoder.
*
* @return gint
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise system error..
*
*/
IMPORT_C gint GetCNG(gboolean& cng);
@@ -133,7 +136,7 @@
* Sets PLC feature on or off.
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise system error..
* TMS_RESULT_INVALID_STATE if this method is used during active
* decoding operation.
* TMS_RESULT_FEATURE_NOT_SUPPORTED if this method is not implemented
@@ -151,7 +154,8 @@
* Current CNG setting of the decoder.
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
*
*/
IMPORT_C gint GetPlc(gboolean& plc);
@@ -166,7 +170,8 @@
* Sets VAD feature on or off.
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
* TMS_RESULT_FEATURE_NOT_SUPPORTED if this method is not implemented
* by the adaptation.
*
@@ -182,7 +187,8 @@
* Current VAD setting of the encoder.
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
*
*/
IMPORT_C gint GetVADMode(gboolean& vad);
--- a/mmmw_plat/telephony_multimedia_service_api/inc/tmsg729format.h Tue May 11 16:42:02 2010 +0300
+++ b/mmmw_plat/telephony_multimedia_service_api/inc/tmsg729format.h Tue May 25 13:16:00 2010 +0300
@@ -55,7 +55,8 @@
* Sets VAD feature on or off.
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
* TMS_RESULT_FEATURE_NOT_SUPPORTED if this method is not implemented
* by the adaptation.
* TMS_RESULT_DOES_NOT_EXIST if the custom interface handle does
@@ -73,7 +74,8 @@
* Current VAD setting of the encoder.
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
*
*/
IMPORT_C gint GetVADMode(gboolean& vad);
--- a/mmmw_plat/telephony_multimedia_service_api/inc/tmsgaineffect.h Tue May 11 16:42:02 2010 +0300
+++ b/mmmw_plat/telephony_multimedia_service_api/inc/tmsgaineffect.h Tue May 25 13:16:00 2010 +0300
@@ -94,7 +94,8 @@
* Gain level to be set.
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
*
*/
IMPORT_C gint SetLevel(const guint level);
@@ -106,7 +107,8 @@
* Current mic gain level.
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
*
*/
IMPORT_C gint GetLevel(guint& level);
@@ -118,7 +120,8 @@
* Max gain level.
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
*
*/
IMPORT_C gint GetMaxLevel(guint& level);
@@ -132,7 +135,8 @@
* Variable that contains the effect type on return.
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
*
*/
IMPORT_C virtual gint GetType(TMSEffectType& effecttype);
--- a/mmmw_plat/telephony_multimedia_service_api/inc/tmsglobalgaineffect.h Tue May 11 16:42:02 2010 +0300
+++ b/mmmw_plat/telephony_multimedia_service_api/inc/tmsglobalgaineffect.h Tue May 25 13:16:00 2010 +0300
@@ -96,7 +96,8 @@
* Gain level to be set.
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
*
*/
IMPORT_C gint SetLevel(const guint level);
@@ -108,7 +109,8 @@
* Current mic gain level.
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
*
*/
IMPORT_C gint GetLevel(guint& level);
@@ -120,7 +122,8 @@
* Max mic gain level.
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
*
*/
IMPORT_C gint GetMaxLevel(guint& level);
@@ -132,7 +135,8 @@
* Type of the effect object (TMS_EFFECT_GLOBAL_GAIN).
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
*
*/
IMPORT_C virtual gint GetType(TMSEffectType& effecttype);
--- a/mmmw_plat/telephony_multimedia_service_api/inc/tmsglobalrouting.h Tue May 11 16:42:02 2010 +0300
+++ b/mmmw_plat/telephony_multimedia_service_api/inc/tmsglobalrouting.h Tue May 25 13:16:00 2010 +0300
@@ -111,7 +111,8 @@
*
* @return
* TMS_RESULT_INVALID_ARGUMENT if set to TMS_AUDIO_OUTPUT_NONE.
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
*
*/
IMPORT_C gint SetOutput(const TMSAudioOutput output);
@@ -126,7 +127,8 @@
* Current audio output device.
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
*
*/
IMPORT_C gint GetOutput(TMSAudioOutput& output);
@@ -141,7 +143,8 @@
* Previous audio output device.
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
*
*/
IMPORT_C gint GetPreviousOutput(TMSAudioOutput& output);
@@ -157,7 +160,8 @@
* audio output devices (TMSAudioOutput-type).
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
*
*/
IMPORT_C gint GetAvailableOutputs(OutputVector& outputs);
--- a/mmmw_plat/telephony_multimedia_service_api/inc/tmsglobalvoleffect.h Tue May 11 16:42:02 2010 +0300
+++ b/mmmw_plat/telephony_multimedia_service_api/inc/tmsglobalvoleffect.h Tue May 25 13:16:00 2010 +0300
@@ -95,7 +95,8 @@
* @param level
* the volume level to be set.
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
*/
IMPORT_C gint SetLevel(const guint level);
@@ -106,7 +107,8 @@
* Volume level to be set.
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
*
*/
IMPORT_C gint GetLevel(guint& level);
@@ -118,7 +120,8 @@
* Max volume level.
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
*
*/
IMPORT_C gint GetMaxLevel(guint& level);
@@ -130,7 +133,8 @@
* Type of the effect object (TMS_EFFECT_GLOBAL_VOL).
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
*
*/
IMPORT_C virtual gint GetType(TMSEffectType& effecttype);
--- a/mmmw_plat/telephony_multimedia_service_api/inc/tmsilbcformat.h Tue May 11 16:42:02 2010 +0300
+++ b/mmmw_plat/telephony_multimedia_service_api/inc/tmsilbcformat.h Tue May 25 13:16:00 2010 +0300
@@ -59,7 +59,8 @@
* Sets selected iLBC encoding or decoding mode.
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
* TMS_RESULT_INVALID_STATE if this method is used during active
* encoding or decoding operation.
* TMS_RESULT_FEATURE_NOT_SUPPORTED if this method is not implemented
@@ -84,7 +85,8 @@
* Returns current iLBC encoding or decoding mode.
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
*
*/
IMPORT_C gint GetMode(TMSILBCCodecMode& mode);
@@ -100,7 +102,8 @@
* Sets CNG feature on or off.
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
* TMS_RESULT_INVALID_STATE if this method is used during active
* decoding operation.
* TMS_RESULT_FEATURE_NOT_SUPPORTED if this method is not implemented
@@ -121,7 +124,8 @@
* Current CNG setting of the decoder.
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
*
*/
IMPORT_C gint GetCNG(gboolean& cng);
@@ -136,7 +140,8 @@
* Sets VAD feature on or off.
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
* TMS_RESULT_FEATURE_NOT_SUPPORTED if this method is not implemented
* by the adaptation.
* TMS_RESULT_DOES_NOT_EXIST if the custom interface handle does
@@ -154,7 +159,8 @@
* Current VAD setting of the encoder.
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
*
*/
IMPORT_C gint GetVADMode(gboolean& vad);
--- a/mmmw_plat/telephony_multimedia_service_api/inc/tmsmicsource.h Tue May 11 16:42:02 2010 +0300
+++ b/mmmw_plat/telephony_multimedia_service_api/inc/tmsmicsource.h Tue May 25 13:16:00 2010 +0300
@@ -51,7 +51,8 @@
* The type of sink object (TMS_SOURCE_MIC).
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
*
*/
IMPORT_C virtual gint GetType(TMSSourceType& sourcetype);
--- a/mmmw_plat/telephony_multimedia_service_api/inc/tmsmodemsink.h Tue May 11 16:42:02 2010 +0300
+++ b/mmmw_plat/telephony_multimedia_service_api/inc/tmsmodemsink.h Tue May 25 13:16:00 2010 +0300
@@ -51,7 +51,8 @@
* The type of sink object (TMS_SINK_MODEM).
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
*
*/
IMPORT_C virtual gint GetType(TMSSinkType& sinktype);
--- a/mmmw_plat/telephony_multimedia_service_api/inc/tmsmodemsource.h Tue May 11 16:42:02 2010 +0300
+++ b/mmmw_plat/telephony_multimedia_service_api/inc/tmsmodemsource.h Tue May 25 13:16:00 2010 +0300
@@ -51,7 +51,8 @@
* The type of sink object (TMS_SOURCE_MODEM).
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
*
*/
IMPORT_C virtual gint GetType(TMSSourceType& sourcetype);
--- a/mmmw_plat/telephony_multimedia_service_api/inc/tmsspeakersink.h Tue May 11 16:42:02 2010 +0300
+++ b/mmmw_plat/telephony_multimedia_service_api/inc/tmsspeakersink.h Tue May 25 13:16:00 2010 +0300
@@ -51,7 +51,8 @@
* The type of sink object (TMS_SINK_SPEAKER).
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
*
*/
IMPORT_C virtual gint GetType(TMSSinkType& sinktype);
--- a/mmmw_plat/telephony_multimedia_service_api/inc/tmsstream.h Tue May 11 16:42:02 2010 +0300
+++ b/mmmw_plat/telephony_multimedia_service_api/inc/tmsstream.h Tue May 25 13:16:00 2010 +0300
@@ -254,7 +254,7 @@
* sink is re-claimed by the client.
*
* @param sink
- * Dink to removed from the stream.
+ * Sink to removed from the stream.
*
* @return
* TMS_RESULT_SUCCESS if sink is removed successfully from the stream.
@@ -385,6 +385,17 @@
IMPORT_C gint GetState();
/**
+ * Get stream ID.
+ *
+ * This function can be called at any time.
+ *
+ * @return
+ * Unique ID of the stream.
+ *
+ */
+ IMPORT_C gint GetStreamId();
+
+ /**
* Get stream type.
*
* This function can be called at any time.
@@ -397,17 +408,6 @@
* Stream type indicating whether it is an uplink or downlink.
*
*/
- IMPORT_C gint GetStreamId();
-
- /**
- * Get stream ID.
- *
- * This function can be called at any time.
- *
- * @return
- * Unique ID of the stream.
- *
- */
IMPORT_C gint GetStreamType();
/**
--- a/mmmw_plat/telephony_multimedia_service_api/inc/tmsvolumeeffect.h Tue May 11 16:42:02 2010 +0300
+++ b/mmmw_plat/telephony_multimedia_service_api/inc/tmsvolumeeffect.h Tue May 25 13:16:00 2010 +0300
@@ -96,7 +96,8 @@
* Volume level to be set.
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
*
*/
IMPORT_C gint SetLevel(const guint level);
@@ -108,7 +109,8 @@
* Volume level.
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
*
*/
IMPORT_C gint GetLevel(guint& level);
@@ -120,7 +122,8 @@
* Max volume level.
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
*
*/
IMPORT_C gint GetMaxLevel(guint& level);
@@ -134,7 +137,8 @@
* Variable that contains the effect type on return.
*
* @return
- * TMS_RESULT_SUCCESS if the operation was successful.
+ * TMS_RESULT_SUCCESS if the operation was successful otherwise
+ * system error.
*
*/
IMPORT_C gint GetType(TMSEffectType& effecttype);
--- a/mmmw_plat/telephony_multimedia_service_api/tsrc/TmsAudioServicesTestClass/sis/create_sis.bat Tue May 11 16:42:02 2010 +0300
+++ b/mmmw_plat/telephony_multimedia_service_api/tsrc/TmsAudioServicesTestClass/sis/create_sis.bat Tue May 25 13:16:00 2010 +0300
@@ -18,5 +18,5 @@
rem
del TmsAudioServicesTestClass.sis*
-makesis TmsAudioServicesTestClass.pkg TmsAudioServicesTestClass.sis
+makesis ..\group\TmsAudioServicesTestClass.pkg TmsAudioServicesTestClass.sis
rem signsis TmsAudioServicesTestClass.sis TmsAudioServicesTestClass.sisx rd.crt rd.key
--- a/mmserv/metadatautility/EABI/MetaDataUtilityU.DEF Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/metadatautility/EABI/MetaDataUtilityU.DEF Tue May 25 13:16:00 2010 +0300
@@ -71,4 +71,6 @@
_ZN16CMetaDataUtility14ParseChunkDataEv @ 70 NONAME
_ZN16CMetaDataUtility15IsChunkDataModeEv @ 71 NONAME
_ZN16CMetaDataUtility16ProcessChunkDataERK6TDesC8i @ 72 NONAME
+ _ZTI18CHXMetaDataUtility @ 73 NONAME
+ _ZTV18CHXMetaDataUtility @ 74 NONAME
--- a/mmserv/metadatautility/Src/MetaDataParser.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/metadatautility/Src/MetaDataParser.cpp Tue May 25 13:16:00 2010 +0300
@@ -1277,6 +1277,26 @@
}
// -----------------------------------------------------------------------------
+// CMetaDataParser::CommonParseDesL
+// -----------------------------------------------------------------------------
+//
+void CMetaDataParser::CommonParseDesL(
+ const RArray<TMetaDataFieldId>& aWantedFields,
+ CMetaDataFieldContainer& aContainer )
+ {
+#ifdef _DEBUG
+ RDebug::Print(_L("CMetaDataParser::CommonParseDesL"));
+#endif
+
+ //Since this is for descriptor "source", by default it is not a DRM Protected file
+ _LIT(KNoProtection, "0");
+ aContainer.AppendL( EMetaDataProtected, KNoProtection );
+
+ //Continue parsing the file
+ ParseL(aWantedFields, aContainer);
+ }
+
+// -----------------------------------------------------------------------------
// CMetaDataParser::GetProtectedL
// -----------------------------------------------------------------------------
//
--- a/mmserv/metadatautility/Src/MetaDataParser.h Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/metadatautility/Src/MetaDataParser.h Tue May 25 13:16:00 2010 +0300
@@ -128,6 +128,17 @@
CMetaDataFieldContainer& aContainer );
/**
+ * Parses the common metadata, the metadata fields are
+ * inserted into the container.
+ * @since 9.2
+ * @param aWantedFields An array of TMetaDataFieldId's. Empty array is interpreted as all fields.
+ * @param aContainer On return, metadata found in aSource is stored here
+ * @return void
+ */
+ void CommonParseDesL( const RArray<TMetaDataFieldId>& aWantedFields,
+ CMetaDataFieldContainer& aContainer );
+
+ /**
* Append DRM Protected data to the container.
* @param aSource a Metadata source file.
* @param aContainer On return, metadata ptotected data is stored here
--- a/mmserv/metadatautility/Src/MetaDataParserRA.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/metadatautility/Src/MetaDataParserRA.cpp Tue May 25 13:16:00 2010 +0300
@@ -51,7 +51,7 @@
{
if ( ValidateL() )
{
- iExists = TRUE;
+// iExists = TRUE;
iHxMetaDataUtility = CHXMetaDataUtility::NewL();
}
else
@@ -122,6 +122,9 @@
RFile rFile;
rFile.Duplicate( ((CMetaDataSourceFile&)iSource).FileHandler() );
TRAPD(err, iHxMetaDataUtility->OpenFileL((RFile &)rFile)); // casting necessary--compile error
+#ifdef _DEBUG
+ RDebug::Print(_L("CMetaDataParserRA::ParseL: Open File err = %d"), err);
+#endif
rFile.Close();
User::LeaveIfError(err);
}
--- a/mmserv/metadatautility/Src/MetaDataUtilityBody.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/metadatautility/Src/MetaDataUtilityBody.cpp Tue May 25 13:16:00 2010 +0300
@@ -152,7 +152,7 @@
iParser = FindParserDesL(aDes);
if ( iParser )
{
- iParser->CommonParseL((CMetaDataSourceFile*)iSource, aWantedFields, *iContainer);
+ iParser->CommonParseDesL(aWantedFields, *iContainer);
}
}
@@ -697,7 +697,7 @@
}
if ( iParser )
{
- iParser->CommonParseL((CMetaDataSourceFile*)iSource, aWantedFields, *iContainer);
+ iParser->CommonParseDesL(aWantedFields, *iContainer);
}
}
--- a/mmserv/radioutility/radioserver/Server/Src/RadioServer.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/radioutility/radioserver/Server/Src/RadioServer.cpp Tue May 25 13:16:00 2010 +0300
@@ -3032,7 +3032,11 @@
void CRadioServer::CompleteAsyncRequest(
TInt aErrorCode )
{
- if ( iAsyncRequest && !(iAsyncRequest->iMessage.IsNull()) )
+ if ( !iAsyncRequest )
+ {
+ RADIO_RDEBUG_INT(_L("[RADIO-SVR] CompleteAsyncRequest(%d) - iAsyncRequest NULL"), aErrorCode);
+ }
+ else if ( !(iAsyncRequest->iMessage.IsNull()) )
{
RADIO_RDEBUG_INT2(_L("[RADIO-SVR] CompleteAsyncRequest(%d, %d) - Client alive"), iAsyncRequest->iType, aErrorCode);
iAsyncRequest->iMessage.Complete(aErrorCode);
@@ -3055,7 +3059,11 @@
void CRadioServer::CompleteSyncRequest(
TInt aErrorCode )
{
- if ( iSyncRequest && !(iSyncRequest->iMessage.IsNull()) )
+ if ( !iSyncRequest )
+ {
+ RADIO_RDEBUG_INT(_L("[RADIO-SVR] CompleteSyncRequest(%d) - iSyncRequest NULL"), aErrorCode);
+ }
+ else if ( !(iSyncRequest->iMessage.IsNull()) )
{
RADIO_RDEBUG_INT2(_L("[RADIO-SVR] CompleteSyncRequest(%d, %d) - Client alive"), iSyncRequest->iType, aErrorCode);
iSyncRequest->iMessage.Complete(aErrorCode);
--- a/mmserv/tms/inc/tmsclientserver.h Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/inc/tmsclientserver.h Tue May 25 13:16:00 2010 +0300
@@ -101,7 +101,8 @@
const TUid KTMSPropertyCategory = {0x10207C7C};
// server name and UID
-_LIT(KTMSServerName, "tmsserver");
+_LIT(KTMSServerFile, "tmsserver");
+_LIT(KTMSServerName, "!TmsServer");
const TUid KTMSServerUid3 = {0x10207C7C};
const TUid KUidTMSCallServerUid3 = {0x10207C78};
--- a/mmserv/tms/inc/tmsmembuffer.h Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/inc/tmsmembuffer.h Tue May 25 13:16:00 2010 +0300
@@ -34,56 +34,56 @@
static gint Create(guint size, TMSBuffer*& tmsbuffer);
static gint Create(guint size, guint8* dataptr, TMSBuffer*& tmsbuffer);
- // Implementation of TMSBuffer interface begins
+ /*
+ * Returns buffer type.
+ *
+ * @param buftype buffer type
+ *
+ */
virtual gint GetType(TMSBufferType& buftype);
+
/**
- Gets the timestamp on the Buffer so that the framework can
- determine the time at which this buffer has to be rendered
- by the output device sink.
-
- @param ts
- timestamp in microseconds
-
+ * Gets the timestamp on the Buffer so that the framework can
+ * determine the time at which this buffer has to be rendered
+ * by the output device sink.
+ *
+ * @param ts buffer timestamp in microseconds
+ *
*/
virtual gint GetTimeStamp(guint64& ts);
/**
- Sets the timestamp on the Buffer so that the framework can
- determine the time at which this buffer has to be rendered
- by the output device sink.
-
- @param ts
- timestamp in milliseconds
-
+ * Sets the timestamp on the Buffer so that the framework can
+ * determine the time at which this buffer has to be rendered
+ * by the output device sink.
+ *
+ * @param ts timestamp in milliseconds
+ *
*/
virtual gint SetTimeStamp(const guint64 ts);
/**
- Gets the size of data in the buffer specified by the client.
-
- @param size
- size of data in bytes
-
+ * Gets the size of data in the buffer specified by the client.
+ *
+ * @param size size of data in bytes
+ *
*/
virtual gint GetDataSize(guint& size);
/**
- Sets the size of data in the buffer after the client
- fill it.
-
- @param size
- size of data in bytes
-
+ * Sets the size of data in the buffer after the client fill it.
+ *
+ * @param size size of data in bytes
+ *
*/
virtual gint SetDataSize(const guint size);
/**
- Gets the pointer to the memory location associated with this
- buffer where the data is stored.
-
- @param bufptr
- ptr to the data stored in the buffer.
-
+ * Gets the pointer to the memory location associated with this
+ * buffer where the data is stored.
+ *
+ * @param bufptr ptr to the data stored in the buffer.
+ *
*/
virtual gint GetDataPtr(guint8*& bufptr);
--- a/mmserv/tms/inc/tmsproxy.h Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/inc/tmsproxy.h Tue May 25 13:16:00 2010 +0300
@@ -95,6 +95,8 @@
virtual void QueueEvent(gint aEventType, gint aError, void* event_data);
private:
+ gint StartServer();
+
void PopulateArrayL(TMSClientServerRequest aRequest,
RArray<TUint32>& aDecoders, gint aCount);
void GetAvailableOutputsL(OutputVector& outputs);
--- a/mmserv/tms/tmscallserver/inc/tmscalladpt.h Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmscallserver/inc/tmscalladpt.h Tue May 25 13:16:00 2010 +0300
@@ -29,11 +29,12 @@
public:
static gint CreateCallL(gint callType, TMSCallAdpt*& callAdpt);
virtual ~TMSCallAdpt();
+
+ // From TMSStream
virtual gint CreateStream(TMSCallType callType,
TMSStreamType strmType, gint& outStrmId) = 0;
- virtual gint InitStreamL(TMSCallType callType,
- TMSStreamType strmType, gint strmId, TMSFormatType frmtType,
- const RMessage2& aMessage) = 0;
+ virtual gint InitStream(TMSCallType callType, TMSStreamType strmType,
+ gint strmId, TMSFormatType frmtType, const RMessage2& aMessage) = 0;
virtual gint StartStream(TMSCallType callType,
TMSStreamType strmType, gint strmId) = 0;
virtual gint PauseStream(TMSCallType callType,
@@ -52,6 +53,7 @@
const TMSStreamType strmType, const gint strmId,
const guint32 key, RChunk& chunk) = 0;
+ // From TMS effects
virtual gint GetMaxVolume(guint& volume) = 0;
virtual gint SetVolume(const guint volume) = 0;
virtual gint GetVolume(guint& volume) = 0;
@@ -65,6 +67,7 @@
virtual gint SetGlobalGain(const guint gain) = 0;
virtual gint GetGlobalGain(guint& gain) = 0;
+ // From TMS formats
virtual gint GetCodecMode(const TMSFormatType fmttype,
const TMSStreamType strmtype, gint& mode) = 0;
virtual gint SetCodecMode(const TMSFormatType fmttype,
@@ -79,6 +82,8 @@
virtual gint SetCNG(const TMSFormatType fmttype, const gboolean cng) = 0;
virtual gint GetPlc(const TMSFormatType fmttype, gboolean& plc) = 0;
virtual gint SetPlc(const TMSFormatType fmttype, const gboolean plc) = 0;
+
+ // From TMS routing
virtual gint SetOutput(TMSAudioOutput output) = 0;
virtual gint GetOutput(TMSAudioOutput& output) = 0;
virtual gint GetPreviousOutput(TMSAudioOutput& output) = 0;
--- a/mmserv/tms/tmscallserver/inc/tmscallcsadpt.h Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmscallserver/inc/tmscallcsadpt.h Tue May 25 13:16:00 2010 +0300
@@ -46,8 +46,8 @@
virtual gint CreateStream(TMSCallType callType, TMSStreamType strmType,
gint& outStrmId);
- virtual gint InitStreamL(TMSCallType callType, TMSStreamType strmType,
- gint strmId, TMSFormatType frmtType, const RMessage2& aMessage);
+ virtual gint InitStream(TMSCallType callType, TMSStreamType strmType,
+ gint strmId, TMSFormatType frmtType, const RMessage2& message);
virtual gint StartStream(TMSCallType callType, TMSStreamType strmType,
gint strmId);
virtual gint PauseStream(TMSCallType callType, TMSStreamType strmType,
@@ -65,6 +65,8 @@
virtual gint GetDataXferBufferHndl(const TMSCallType callType,
const TMSStreamType strmType, const gint strmId,
const guint32 key, RChunk& chunk);
+
+ // From TMS effects
virtual gint GetMaxVolume(guint& volume);
virtual gint SetVolume(const guint volume);
virtual gint GetVolume(guint& volume);
@@ -78,6 +80,7 @@
virtual gint SetGlobalGain(const guint gain);
virtual gint GetGlobalGain(guint& gain);
+ // From TMS formats
virtual gint GetCodecMode(const TMSFormatType fmttype,
const TMSStreamType strmtype, gint& mode);
virtual gint SetCodecMode(const TMSFormatType fmttype,
@@ -93,14 +96,12 @@
virtual gint GetPlc(const TMSFormatType fmttype, gboolean& plc);
virtual gint SetPlc(const TMSFormatType fmttype, const gboolean plc);
+ // From TMS audio routing
virtual gint SetOutput(TMSAudioOutput output);
virtual gint GetOutput(TMSAudioOutput& output);
virtual gint GetPreviousOutput(TMSAudioOutput& output);
virtual gint GetAvailableOutputsL(gint& count, CBufFlat*& outputsbuffer);
- void NotifyClient(const gint strmId, const gint aCommand,
- const gint aStatus = KErrNone, const gint64 aInt64 = TInt64(0));
-
//From TMSCSPDevSoundObserver
void DownlinkInitCompleted(TInt status);
void UplinkInitCompleted(TInt status);
@@ -109,13 +110,15 @@
void UplinkActivationFailed();
void DownlinkActivationFailed();
-protected:
+private:
void AvailableOutputsChanged(
CTelephonyAudioRouting& aTelephonyAudioRouting);
void OutputChanged(CTelephonyAudioRouting& aTelephonyAudioRouting);
void SetOutputComplete(CTelephonyAudioRouting& aTelephonyAudioRouting,
gint aError);
void GetSupportedBitRatesL(CBufFlat*& brbuffer);
+ void NotifyClient(const gint strmId, const gint command,
+ const gint status = KErrNone, const gint64 int64 = TInt64(0));
private:
gint iNextStreamId;
--- a/mmserv/tms/tmscallserver/inc/tmscallipadpt.h Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmscallserver/inc/tmscallipadpt.h Tue May 25 13:16:00 2010 +0300
@@ -37,14 +37,14 @@
public:
// Constractor
static TMSCallIPAdpt* NewL();
-
virtual ~TMSCallIPAdpt();
virtual gint PostConstruct();
+ // From TMSStream
virtual gint CreateStream(TMSCallType callType, TMSStreamType strmType,
gint& outStrmId);
- virtual gint InitStreamL(TMSCallType callType, TMSStreamType strmType,
- gint strmId, TMSFormatType frmtType, const RMessage2& aMessage);
+ virtual gint InitStream(TMSCallType callType, TMSStreamType strmType,
+ gint strmId, TMSFormatType frmtType, const RMessage2& message);
virtual gint StartStream(TMSCallType callType, TMSStreamType strmType,
gint strmId);
virtual gint PauseStream(TMSCallType callType, TMSStreamType strmType,
@@ -63,6 +63,7 @@
const TMSStreamType strmType, const gint strmId,
const guint32 key, RChunk& chunk);
+ // From TMS effects
virtual gint GetMaxVolume(guint& volume);
virtual gint SetVolume(const guint volume);
virtual gint GetVolume(guint& volume);
@@ -76,6 +77,7 @@
virtual gint SetGlobalGain(const guint gain);
virtual gint GetGlobalGain(guint& gain);
+ // From TMS formats
virtual gint GetCodecMode(const TMSFormatType fmttype,
const TMSStreamType strmtype, gint& mode);
virtual gint SetCodecMode(const TMSFormatType fmttype,
@@ -91,11 +93,13 @@
virtual gint GetPlc(const TMSFormatType fmttype, gboolean& plc);
virtual gint SetPlc(const TMSFormatType fmttype, const gboolean plc);
+ // From TMS audio output
virtual gint SetOutput(TMSAudioOutput output);
virtual gint GetOutput(TMSAudioOutput& output);
virtual gint GetPreviousOutput(TMSAudioOutput& output);
- virtual gint GetAvailableOutputsL(TInt& count, CBufFlat*& outputsbuffer);
+ virtual gint GetAvailableOutputsL(gint& count, CBufFlat*& outputsbuffer);
+ // From TMS codec formats
gint SetIlbcCodecMode(const gint mode, const TMSStreamType strmtype);
gint GetIlbcCodecMode(gint& mode, const TMSStreamType strmtype);
gint SetG711CodecMode(const gint mode, const TMSStreamType strmtype);
@@ -106,22 +110,21 @@
gint ConcealErrorForNextBuffer();
gint BadLsfNextBuffer();
- gint OpenDownlinkL(const RMessage2& aMessage);
- gint OpenUplinkL(const RMessage2& aMessage);
- void SetFormat(const gint strmId, const TUint32 aFormat);
+ gint OpenDownlinkL(const RMessage2& message);
+ gint OpenUplinkL(const RMessage2& message);
+ void SetFormat(const gint strmId, const guint32 aFormat);
- void BufferFilledL(TUint dataSize);
+ void BufferFilledL(guint dataSize);
void BufferEmptiedL();
gint GetDataXferChunkHndl(const TMSStreamType strmType,
- const TUint32 key, RChunk& chunk);
+ const guint32 key, RChunk& chunk);
private:
void ConstructL();
TMSCallIPAdpt();
- void NotifyClient(const gint strmId, const TInt aCommand,
- const TInt aStatus = KErrNone, const TInt64 aInt64 = TInt64(0));
- //void DetermineG711FrameRateL(); //G711 10/20ms
+ void NotifyClient(const gint strmId, const gint aCommand,
+ const gint aStatus = KErrNone, const gint64 aInt64 = gint64(0));
void GetSupportedBitRatesL(CBufFlat*& brbuffer);
private:
@@ -140,13 +143,13 @@
TmsMsgBuf iMsgBuffer;
TMMFPrioritySettings iPriority;
- TUint32 iUpFourCC;
- TUint32 iDnFourCC;
- TInt iMaxVolume;
- TInt iMaxGain;
- RArray<TUint> iArrBitrates;
+ guint32 iUpFourCC;
+ guint32 iDnFourCC;
+ gint iMaxVolume;
+ gint iMaxGain;
+ RArray<guint> iArrBitrates;
RArray<TFourCC> iCodecs;
- TInt iCodecsCount;
+ gint iCodecsCount;
};
--- a/mmserv/tms/tmscallserver/src/tmscallcsadpt.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmscallserver/src/tmscallcsadpt.cpp Tue May 25 13:16:00 2010 +0300
@@ -138,9 +138,8 @@
//
// -----------------------------------------------------------------------------
//
-gint TMSCallCSAdpt::InitStreamL(TMSCallType /*callType*/,
- TMSStreamType strmType, gint strmId, TMSFormatType /*frmtType*/,
- const RMessage2& aMessage)
+gint TMSCallCSAdpt::InitStream(TMSCallType /*callType*/, TMSStreamType strmType,
+ gint strmId, TMSFormatType /*frmtType*/, const RMessage2& message)
{
TRACE_PRN_FN_ENT;
gint status(TMS_RESULT_SUCCESS);
@@ -148,13 +147,14 @@
switch (strmType)
{
case TMS_STREAM_UPLINK:
+ {
if (strmId == iUplinkStreamId)
{
// Open message queue handling client-server communication
if (iMsgQueueUp.Handle() <= 0)
{
// Third argument in TMSCallProxy::InitStream
- status = iMsgQueueUp.Open(aMessage, 1);
+ status = iMsgQueueUp.Open(message, 1);
}
if (status == TMS_RESULT_SUCCESS)
{
@@ -167,14 +167,16 @@
status = TMS_RESULT_DOES_NOT_EXIST;
}
break;
+ }
case TMS_STREAM_DOWNLINK:
+ {
if (strmId == iDnlinkStreamId)
{
// Open message queue handling client-server communication
if (iMsgQueueDn.Handle() <= 0)
{
// Third argument in TMSCallProxy::InitStream
- status = iMsgQueueDn.Open(aMessage, 1);
+ status = iMsgQueueDn.Open(message, 1);
}
if (status == TMS_RESULT_SUCCESS)
{
@@ -182,10 +184,10 @@
if (status == TMS_RESULT_SUCCESS)
{
TRAP(status, iRouting =
- CTelephonyAudioRouting::NewL(*this));
+ CTelephonyAudioRouting::NewL(*this));
if (status == TMS_RESULT_SUCCESS)
{
- iTarSettings = TMSTarSettings::NewL();
+ TRAP(status, iTarSettings = TMSTarSettings::NewL());
}
}
}
@@ -196,9 +198,12 @@
status = TMS_RESULT_DOES_NOT_EXIST;
}
break;
+ }
default:
+ {
status = TMS_RESULT_STREAM_TYPE_NOT_SUPPORTED;
break;
+ }
}
TRACE_PRN_IF_ERR(status);
@@ -895,7 +900,6 @@
{
tmsoutput = TOTMSOUTPUT(availableOutputs[i]);
stream.WriteUint32L(tmsoutput);
- //TRACE_PRN_N1(_L("TMS->CallIPAdpt: outputs: [%d]"), availableOutputs[i]);
}
CleanupStack::PopAndDestroy(&stream);
@@ -914,7 +918,7 @@
//
// -----------------------------------------------------------------------------
//
-void TMSCallCSAdpt::DownlinkInitCompleted(TInt status)
+void TMSCallCSAdpt::DownlinkInitCompleted(gint status)
{
TRACE_PRN_FN_ENT;
NotifyClient(iDnlinkStreamId, ECmdDownlinkInitComplete, status, 0);
@@ -926,7 +930,7 @@
//
// -----------------------------------------------------------------------------
//
-void TMSCallCSAdpt::UplinkInitCompleted(TInt status)
+void TMSCallCSAdpt::UplinkInitCompleted(gint status)
{
TRACE_PRN_FN_ENT;
NotifyClient(iUplinkStreamId, ECmdUplinkInitComplete, status, 0);
@@ -1029,7 +1033,6 @@
{
iTarSettings->SetTar(pckg, ETrue);
}
- //TRACE_PRN_IF_ERR(aError);
TRACE_PRN_FN_EXT;
}
@@ -1038,11 +1041,11 @@
//
// -----------------------------------------------------------------------------
//
-void TMSCallCSAdpt::NotifyClient(const gint strmId, const gint aCommand,
- const gint aStatus, const gint64 /*aInt64*/)
+void TMSCallCSAdpt::NotifyClient(const gint strmId, const gint command,
+ const gint status, const gint64 /*int64*/)
{
- iMsgBuffer.iRequest = aCommand;
- iMsgBuffer.iStatus = aStatus;
+ iMsgBuffer.iRequest = command;
+ iMsgBuffer.iStatus = status;
if (strmId == iUplinkStreamId)
{
--- a/mmserv/tms/tmscallserver/src/tmscallipadpt.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmscallserver/src/tmscallipadpt.cpp Tue May 25 13:16:00 2010 +0300
@@ -158,14 +158,13 @@
//
// -----------------------------------------------------------------------------
//
-gint TMSCallIPAdpt::InitStreamL(TMSCallType /*callType*/,
- TMSStreamType strmType, gint strmId, TMSFormatType frmtType,
- const RMessage2& aMessage)
+gint TMSCallIPAdpt::InitStream(TMSCallType /*callType*/, TMSStreamType strmType,
+ gint strmId, TMSFormatType frmtType, const RMessage2& message)
{
TRACE_PRN_FN_ENT;
gint status(TMS_RESULT_SUCCESS);
- TUint32 fourCC = TOFOURCC(frmtType);
+ guint32 fourCC = TOFOURCC(frmtType);
if (fourCC == NULL)
{
return TMS_RESULT_INVALID_ARGUMENT;
@@ -179,7 +178,7 @@
if (strmId == iUplinkStreamId)
{
SetFormat(iUplinkStreamId, fourCC);
- status = OpenUplinkL(aMessage);
+ status = OpenUplinkL(message);
NotifyClient(iUplinkStreamId, ECmdUplinkInitComplete, status);
}
break;
@@ -190,7 +189,7 @@
if (strmId == iDnlinkStreamId)
{
SetFormat(iDnlinkStreamId, fourCC);
- status = OpenDownlinkL(aMessage);
+ status = OpenDownlinkL(message);
NotifyClient(iDnlinkStreamId, ECmdDownlinkInitComplete, status);
}
break;
@@ -988,7 +987,7 @@
// Method for player initialization.
// -----------------------------------------------------------------------------
//
-gint TMSCallIPAdpt::OpenDownlinkL(const RMessage2& aMessage)
+gint TMSCallIPAdpt::OpenDownlinkL(const RMessage2& message)
{
TRACE_PRN_FN_ENT;
gint status(TMS_RESULT_SUCCESS);
@@ -1010,7 +1009,7 @@
if (iMsgQueueDn.Handle() <= 0)
{
// Second argument in TMSCallProxy::InitStream
- status = iMsgQueueDn.Open(aMessage, 1);
+ status = iMsgQueueDn.Open(message, 1);
}
if (status == TMS_RESULT_SUCCESS)
@@ -1030,7 +1029,7 @@
// Method for recorder initialization.
// -----------------------------------------------------------------------------
//
-gint TMSCallIPAdpt::OpenUplinkL(const RMessage2& aMessage)
+gint TMSCallIPAdpt::OpenUplinkL(const RMessage2& message)
{
TRACE_PRN_FN_ENT;
gint status(TMS_RESULT_SUCCESS);
@@ -1050,7 +1049,7 @@
if (iMsgQueueUp.Handle() <= 0)
{
// Second argument in TMSCallProxy::InitStream
- status = iMsgQueueUp.Open(aMessage, 1);
+ status = iMsgQueueUp.Open(message, 1);
}
if (status == TMS_RESULT_SUCCESS)
@@ -1070,7 +1069,7 @@
//
// -----------------------------------------------------------------------------
//
-void TMSCallIPAdpt::SetFormat(const gint strmId, const TUint32 aFormat)
+void TMSCallIPAdpt::SetFormat(const gint strmId, const guint32 aFormat)
{
if (strmId == iUplinkStreamId)
{
@@ -1087,7 +1086,7 @@
//
// -----------------------------------------------------------------------------
//
-void TMSCallIPAdpt::BufferFilledL(TUint dataSize)
+void TMSCallIPAdpt::BufferFilledL(guint dataSize)
{
if (iIPDownlink)
{
@@ -1114,7 +1113,7 @@
// -----------------------------------------------------------------------------
//
gint TMSCallIPAdpt::GetDataXferChunkHndl(const TMSStreamType strmType,
- const TUint32 key, RChunk& chunk)
+ const guint32 key, RChunk& chunk)
{
TRACE_PRN_FN_ENT;
@@ -1383,8 +1382,8 @@
// TMSCallIPAdpt::NotifyClient
// -----------------------------------------------------------------------------
//
-void TMSCallIPAdpt::NotifyClient(const gint strmId, const TInt aCommand,
- const TInt aStatus, const TInt64 /*aInt64*/)
+void TMSCallIPAdpt::NotifyClient(const gint strmId, const gint aCommand,
+ const gint aStatus, const gint64 /*aInt64*/)
{
iMsgBuffer.iRequest = aCommand;
iMsgBuffer.iStatus = aStatus;
--- a/mmserv/tms/tmscallserver/src/tmscallsession.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmscallserver/src/tmscallsession.cpp Tue May 25 13:16:00 2010 +0300
@@ -25,6 +25,7 @@
using namespace TMS;
const guint KArrayExpandSize = 8;
+const guint KNumOfElements = 10;
// -----------------------------------------------------------------------------
// TMSCallSession::TMSCallSession
@@ -289,7 +290,7 @@
{
TMSCliSrvStreamInitDataStructBufPckg pckg;
aMessage.ReadL(0, pckg);
- status = iCallAdpt->InitStreamL(pckg().CallType, pckg().StreamType,
+ status = iCallAdpt->InitStream(pckg().CallType, pckg().StreamType,
pckg().StreamId, pckg().FormatType, aMessage);
switch (pckg().StreamType)
@@ -1097,7 +1098,7 @@
gint count;
if (iCallAdpt)
{
- CBufFlat* outputbuf = CBufFlat::NewL(10);
+ CBufFlat* outputbuf = CBufFlat::NewL(KNumOfElements);
CleanupStack::PushL(outputbuf);
status = iCallAdpt->GetAvailableOutputsL(count, outputbuf);
--- a/mmserv/tms/tmsfactory/src/tmsfactoryimpl.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmsfactory/src/tmsfactoryimpl.cpp Tue May 25 13:16:00 2010 +0300
@@ -193,7 +193,7 @@
gint TMSFactoryImpl::QueryDevice(const TMSStreamType strmtype)
{
gint ret(TMS_RESULT_SUCCESS);
- TMSProxy* session = new TMSProxy;
+ TMSProxy* session = new TMSProxy();
if (session)
{
if (session->Connect() == TMS_RESULT_SUCCESS)
--- a/mmserv/tms/tmsimpl/src/tmsamrbodyimpl.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmsimpl/src/tmsamrbodyimpl.cpp Tue May 25 13:16:00 2010 +0300
@@ -38,7 +38,7 @@
gint TMSAMRFormatBodyImpl::Create(TMSAMRFormatBody*& bodyimpl)
{
gint ret(TMS_RESULT_INSUFFICIENT_MEMORY);
- TMSAMRFormatBodyImpl* self = new TMSAMRFormatBodyImpl;
+ TMSAMRFormatBodyImpl* self = new TMSAMRFormatBodyImpl();
if (self)
{
ret = self->PostConstruct();
--- a/mmserv/tms/tmsimpl/src/tmsamrimpl.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmsimpl/src/tmsamrimpl.cpp Tue May 25 13:16:00 2010 +0300
@@ -52,7 +52,7 @@
gint TMSAMRFormatImpl::Create(TMSFormat*& tmsformat)
{
gint ret(TMS_RESULT_INSUFFICIENT_MEMORY);
- TMSAMRFormatImpl *self = new TMSAMRFormatImpl;
+ TMSAMRFormatImpl *self = new TMSAMRFormatImpl();
TRACE_PRN_FN_ENT;
if (self)
--- a/mmserv/tms/tmsimpl/src/tmscallbodyimpl.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmsimpl/src/tmscallbodyimpl.cpp Tue May 25 13:16:00 2010 +0300
@@ -31,7 +31,7 @@
gint TMSCallBodyImpl::Create(TMSCallBody*& bodyimpl)
{
gint ret(TMS_RESULT_INSUFFICIENT_MEMORY);
- TMSCallBodyImpl* self = new TMSCallBodyImpl;
+ TMSCallBodyImpl* self = new TMSCallBodyImpl();
if (self)
{
ret = self->PostConstruct();
--- a/mmserv/tms/tmsimpl/src/tmscallimpl.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmsimpl/src/tmscallimpl.cpp Tue May 25 13:16:00 2010 +0300
@@ -66,7 +66,7 @@
guint ctxid)
{
gint ret(TMS_RESULT_INSUFFICIENT_MEMORY);
- TMSCallImpl *self = new TMSCallImpl;
+ TMSCallImpl *self = new TMSCallImpl();
TRACE_PRN_FN_ENT;
if (self)
--- a/mmserv/tms/tmsimpl/src/tmsclientsinkbodyimpl.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmsimpl/src/tmsclientsinkbodyimpl.cpp Tue May 25 13:16:00 2010 +0300
@@ -37,7 +37,7 @@
gint TMSClientSinkBodyImpl::Create(TMSClientSinkBody*& bodyimpl)
{
gint ret(TMS_RESULT_INSUFFICIENT_MEMORY);
- TMSClientSinkBodyImpl* self = new TMSClientSinkBodyImpl;
+ TMSClientSinkBodyImpl* self = new TMSClientSinkBodyImpl();
if (self)
{
ret = self->PostConstruct();
--- a/mmserv/tms/tmsimpl/src/tmsclientsinkimpl.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmsimpl/src/tmsclientsinkimpl.cpp Tue May 25 13:16:00 2010 +0300
@@ -51,7 +51,7 @@
gint TMSClientSinkImpl::Create(TMSSink*& tmssink)
{
gint ret(TMS_RESULT_INSUFFICIENT_MEMORY);
- TMSClientSinkImpl *self = new TMSClientSinkImpl;
+ TMSClientSinkImpl *self = new TMSClientSinkImpl();
TRACE_PRN_FN_ENT;
if (self)
--- a/mmserv/tms/tmsimpl/src/tmsclientsourcebodyimpl.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmsimpl/src/tmsclientsourcebodyimpl.cpp Tue May 25 13:16:00 2010 +0300
@@ -38,7 +38,7 @@
gint TMSClientSourceBodyImpl::Create(TMSClientSourceBody*& bodyimpl)
{
gint ret(TMS_RESULT_INSUFFICIENT_MEMORY);
- TMSClientSourceBodyImpl* self = new TMSClientSourceBodyImpl;
+ TMSClientSourceBodyImpl* self = new TMSClientSourceBodyImpl();
if (self)
{
ret = self->PostConstruct();
--- a/mmserv/tms/tmsimpl/src/tmsclientsourceimpl.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmsimpl/src/tmsclientsourceimpl.cpp Tue May 25 13:16:00 2010 +0300
@@ -51,7 +51,7 @@
gint TMSClientSourceImpl::Create(TMSSource*& tmssource)
{
gint ret(TMS_RESULT_INSUFFICIENT_MEMORY);
- TMSClientSourceImpl *self = new TMSClientSourceImpl;
+ TMSClientSourceImpl *self = new TMSClientSourceImpl();
TRACE_PRN_FN_ENT;
if (self)
--- a/mmserv/tms/tmsimpl/src/tmscscallbodyimpl.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmsimpl/src/tmscscallbodyimpl.cpp Tue May 25 13:16:00 2010 +0300
@@ -45,7 +45,7 @@
gint TMSCSCallBodyImpl::Create(TMSCallBody*& bodyimpl)
{
gint ret(TMS_RESULT_INSUFFICIENT_MEMORY);
- TMSCSCallBodyImpl* self = new TMSCSCallBodyImpl;
+ TMSCSCallBodyImpl* self = new TMSCSCallBodyImpl();
TRACE_PRN_FN_ENT;
if (self)
@@ -67,7 +67,7 @@
gint ret(TMS_RESULT_SUCCESS);
TRACE_PRN_FN_ENT;
- iSession = new TMSCallProxy;
+ iSession = new TMSCallProxy();
TRACE_PRN_FN_ENT;
if (!iSession)
--- a/mmserv/tms/tmsimpl/src/tmsg711bodyimpl.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmsimpl/src/tmsg711bodyimpl.cpp Tue May 25 13:16:00 2010 +0300
@@ -38,7 +38,7 @@
gint TMSG711FormatBodyImpl::Create(TMSG711FormatBody*& bodyimpl)
{
gint ret(TMS_RESULT_INSUFFICIENT_MEMORY);
- TMSG711FormatBodyImpl* self = new TMSG711FormatBodyImpl;
+ TMSG711FormatBodyImpl* self = new TMSG711FormatBodyImpl();
if (self)
{
ret = self->PostConstruct();
--- a/mmserv/tms/tmsimpl/src/tmsg711impl.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmsimpl/src/tmsg711impl.cpp Tue May 25 13:16:00 2010 +0300
@@ -52,7 +52,7 @@
gint TMSG711FormatImpl::Create(TMSFormat*& tmsformat)
{
gint ret(TMS_RESULT_INSUFFICIENT_MEMORY);
- TMSG711FormatImpl *self = new TMSG711FormatImpl;
+ TMSG711FormatImpl *self = new TMSG711FormatImpl();
TRACE_PRN_FN_ENT;
if (self)
--- a/mmserv/tms/tmsimpl/src/tmsg729bodyimpl.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmsimpl/src/tmsg729bodyimpl.cpp Tue May 25 13:16:00 2010 +0300
@@ -38,7 +38,7 @@
gint TMSG729FormatBodyImpl::Create(TMSG729FormatBody*& bodyimpl)
{
gint ret(TMS_RESULT_INSUFFICIENT_MEMORY);
- TMSG729FormatBodyImpl* self = new TMSG729FormatBodyImpl;
+ TMSG729FormatBodyImpl* self = new TMSG729FormatBodyImpl();
if (self)
{
ret = self->PostConstruct();
--- a/mmserv/tms/tmsimpl/src/tmsg729impl.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmsimpl/src/tmsg729impl.cpp Tue May 25 13:16:00 2010 +0300
@@ -52,7 +52,7 @@
gint TMSG729FormatImpl::Create(TMSFormat*& tmsformat)
{
gint ret(TMS_RESULT_INSUFFICIENT_MEMORY);
- TMSG729FormatImpl *self = new TMSG729FormatImpl;
+ TMSG729FormatImpl *self = new TMSG729FormatImpl();
TRACE_PRN_FN_ENT;
if (self)
--- a/mmserv/tms/tmsimpl/src/tmsgaineffectbodyimpl.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmsimpl/src/tmsgaineffectbodyimpl.cpp Tue May 25 13:16:00 2010 +0300
@@ -40,7 +40,7 @@
gint TMSGainEffectBodyImpl::Create(TMSGainEffectBody*& bodyimpl)
{
gint ret(TMS_RESULT_INSUFFICIENT_MEMORY);
- TMSGainEffectBodyImpl* self = new TMSGainEffectBodyImpl;
+ TMSGainEffectBodyImpl* self = new TMSGainEffectBodyImpl();
if (self)
{
ret = self->PostConstruct();
--- a/mmserv/tms/tmsimpl/src/tmsgaineffectimpl.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmsimpl/src/tmsgaineffectimpl.cpp Tue May 25 13:16:00 2010 +0300
@@ -51,7 +51,7 @@
gint TMSGainEffectImpl::Create(TMSEffect*& tmseffect)
{
gint ret(TMS_RESULT_INSUFFICIENT_MEMORY);
- TMSGainEffectImpl *self = new TMSGainEffectImpl;
+ TMSGainEffectImpl *self = new TMSGainEffectImpl();
TRACE_PRN_FN_ENT;
if (self)
--- a/mmserv/tms/tmsimpl/src/tmsglobalgaineffectbodyimpl.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmsimpl/src/tmsglobalgaineffectbodyimpl.cpp Tue May 25 13:16:00 2010 +0300
@@ -46,7 +46,7 @@
gint TMSGlobalGainEffectBodyImpl::Create(TMSGlobalGainEffectBody*& bodyimpl)
{
gint ret(TMS_RESULT_INSUFFICIENT_MEMORY);
- TMSGlobalGainEffectBodyImpl* self = new TMSGlobalGainEffectBodyImpl;
+ TMSGlobalGainEffectBodyImpl* self = new TMSGlobalGainEffectBodyImpl();
if (self)
{
ret = self->PostConstruct();
@@ -64,7 +64,7 @@
{
gint ret(TMS_RESULT_SUCCESS);
iClientId = 1;
- iProxy = new TMSProxy;
+ iProxy = new TMSProxy();
if (!iProxy)
{
ret = TMS_RESULT_INSUFFICIENT_MEMORY;
--- a/mmserv/tms/tmsimpl/src/tmsglobalgaineffectimpl.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmsimpl/src/tmsglobalgaineffectimpl.cpp Tue May 25 13:16:00 2010 +0300
@@ -51,7 +51,7 @@
gint TMSGlobalGainEffectImpl::Create(TMSEffect*& tmseffect)
{
gint ret(TMS_RESULT_INSUFFICIENT_MEMORY);
- TMSGlobalGainEffectImpl *self = new TMSGlobalGainEffectImpl;
+ TMSGlobalGainEffectImpl *self = new TMSGlobalGainEffectImpl();
TRACE_PRN_FN_ENT;
if (self)
--- a/mmserv/tms/tmsimpl/src/tmsglobalroutingbodyimpl.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmsimpl/src/tmsglobalroutingbodyimpl.cpp Tue May 25 13:16:00 2010 +0300
@@ -64,7 +64,7 @@
{
gint ret(TMS_RESULT_SUCCESS);
iClientId = 1;
- iProxy = new TMSProxy;
+ iProxy = new TMSProxy();
if (!iProxy)
{
ret = TMS_RESULT_INSUFFICIENT_MEMORY;
--- a/mmserv/tms/tmsimpl/src/tmsglobalvoleffectbodyimpl.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmsimpl/src/tmsglobalvoleffectbodyimpl.cpp Tue May 25 13:16:00 2010 +0300
@@ -46,7 +46,7 @@
gint TMSGlobalVolEffectBodyImpl::Create(TMSGlobalVolEffectBody*& bodyimpl)
{
gint ret(TMS_RESULT_INSUFFICIENT_MEMORY);
- TMSGlobalVolEffectBodyImpl* self = new TMSGlobalVolEffectBodyImpl;
+ TMSGlobalVolEffectBodyImpl* self = new TMSGlobalVolEffectBodyImpl();
if (self)
{
ret = self->PostConstruct();
@@ -64,7 +64,7 @@
{
gint ret(TMS_RESULT_SUCCESS);
iClientId = 1;
- iProxy = new TMSProxy;
+ iProxy = new TMSProxy();
if (!iProxy)
{
ret = TMS_RESULT_INSUFFICIENT_MEMORY;
--- a/mmserv/tms/tmsimpl/src/tmsglobalvoleffectimpl.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmsimpl/src/tmsglobalvoleffectimpl.cpp Tue May 25 13:16:00 2010 +0300
@@ -51,7 +51,7 @@
gint TMSGlobalVolEffectImpl::Create(TMSEffect*& tmseffect)
{
gint ret(TMS_RESULT_INSUFFICIENT_MEMORY);
- TMSGlobalVolEffectImpl *self = new TMSGlobalVolEffectImpl;
+ TMSGlobalVolEffectImpl *self = new TMSGlobalVolEffectImpl();
TRACE_PRN_FN_ENT;
if (self)
--- a/mmserv/tms/tmsimpl/src/tmsilbcbodyimpl.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmsimpl/src/tmsilbcbodyimpl.cpp Tue May 25 13:16:00 2010 +0300
@@ -38,7 +38,7 @@
gint TMSILBCFormatBodyImpl::Create(TMSILBCFormatBody*& bodyimpl)
{
gint ret(TMS_RESULT_INSUFFICIENT_MEMORY);
- TMSILBCFormatBodyImpl* self = new TMSILBCFormatBodyImpl;
+ TMSILBCFormatBodyImpl* self = new TMSILBCFormatBodyImpl();
if (self)
{
ret = self->PostConstruct();
--- a/mmserv/tms/tmsimpl/src/tmsilbcimpl.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmsimpl/src/tmsilbcimpl.cpp Tue May 25 13:16:00 2010 +0300
@@ -52,7 +52,7 @@
gint TMSILBCFormatImpl::Create(TMSFormat*& tmsformat)
{
gint ret(TMS_RESULT_INSUFFICIENT_MEMORY);
- TMSILBCFormatImpl *self = new TMSILBCFormatImpl;
+ TMSILBCFormatImpl *self = new TMSILBCFormatImpl();
TRACE_PRN_FN_ENT;
if (self)
--- a/mmserv/tms/tmsimpl/src/tmsipcallbodyimpl.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmsimpl/src/tmsipcallbodyimpl.cpp Tue May 25 13:16:00 2010 +0300
@@ -45,7 +45,7 @@
gint TMSIPCallBodyImpl::Create(TMSCallBody*& bodyimpl)
{
gint ret(TMS_RESULT_INSUFFICIENT_MEMORY);
- TMSIPCallBodyImpl* self = new TMSIPCallBodyImpl;
+ TMSIPCallBodyImpl* self = new TMSIPCallBodyImpl();
TRACE_PRN_FN_ENT;
if (self)
@@ -194,7 +194,7 @@
if (itStrm)
{
iStreamsVector.erase(itStrm); // Remove from array
- // Don't delete itStrm as the iterator advanced to the next
+ // Don't delete itStrm as the iterator advanced to the next
// item on the list
ret = TMSStreamImpl::Delete(strm);
}
--- a/mmserv/tms/tmsimpl/src/tmsmembuffer.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmsimpl/src/tmsmembuffer.cpp Tue May 25 13:16:00 2010 +0300
@@ -38,7 +38,7 @@
{
gint ret(TMS_RESULT_INSUFFICIENT_MEMORY);
TRACE_PRN_FN_ENT;
- TMSMemBuffer* self = new TMSMemBuffer;
+ TMSMemBuffer* self = new TMSMemBuffer();
if (self)
{
ret = self->PostConstruct(size);
@@ -57,7 +57,7 @@
{
gint ret(TMS_RESULT_INSUFFICIENT_MEMORY);
TRACE_PRN_FN_ENT;
- TMSMemBuffer* self = new TMSMemBuffer;
+ TMSMemBuffer* self = new TMSMemBuffer();
if (self)
{
self->iDataPtr = dataptr;
@@ -92,15 +92,13 @@
return ret;
}
-// Implementation of TMSBuffer interface begins
/**
- Gets the timestamp on the Buffer so that the framework can
- determine the time at which this buffer has to be rendered
- by the output device sink.
-
- @param ts
- timestamp in microseconds
-
+ * Gets the timestamp on the Buffer so that the framework can
+ * determine the time at which this buffer has to be rendered
+ * by the output device sink.
+ *
+ * @param ts timestamp in microseconds
+ *
*/
gint TMSMemBuffer::GetTimeStamp(guint64& ts)
{
@@ -110,13 +108,12 @@
}
/**
- Sets the timestamp on the Buffer so that the framework can
- determine the time at which this buffer has to be rendered
- by the output device sink.
-
- @param ts
- timestamp in milliseconds
-
+ * Sets the timestamp on the Buffer so that the framework can
+ * determine the time at which this buffer has to be rendered
+ * by the output device sink.
+ *
+ * @param ts timestamp in milliseconds
+ *
*/
gint TMSMemBuffer::SetTimeStamp(const guint64 ts)
{
@@ -126,11 +123,10 @@
}
/**
- Gets the size of data in the buffer specified by the client.
-
- @param size
- size of data in bytes
-
+ * Gets the size of data in the buffer specified by the client.
+ *
+ * @param size size of data in bytes
+ *
*/
gint TMSMemBuffer::GetDataSize(guint& size)
{
@@ -140,27 +136,24 @@
}
/**
- Sets the size of data in the buffer after the client
- fill it.
-
- @param size
- size of data in bytes
-
+ * Sets the size of data in the buffer after the client fill it.
+ *
+ * @param size size of data in bytes
+ *
*/
gint TMSMemBuffer::SetDataSize(const guint size)
{
gint ret(TMS_RESULT_SUCCESS);
- iBufferSize = size;
+ iBufferSize = size; //TODO: should realloc when new size > old size (?)
return ret;
}
/**
- Gets the pointer to the memory location associated with this
- buffer where the data is stored.
-
- @param bufptr
- ptr to the data stored in the buffer.
-
+ * Gets the pointer to the memory location associated with this
+ * buffer where the data is stored.
+ *
+ * @param bufptr ptr to the data stored in the buffer.
+ *
*/
gint TMSMemBuffer::GetDataPtr(guint8*& bufptr)
{
--- a/mmserv/tms/tmsimpl/src/tmsmicsourcebodyimpl.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmsimpl/src/tmsmicsourcebodyimpl.cpp Tue May 25 13:16:00 2010 +0300
@@ -33,7 +33,7 @@
gint TMSMicSourceBodyImpl::Create(TMSMicSourceBody*& bodyimpl)
{
gint ret(TMS_RESULT_INSUFFICIENT_MEMORY);
- TMSMicSourceBodyImpl* self = new TMSMicSourceBodyImpl;
+ TMSMicSourceBodyImpl* self = new TMSMicSourceBodyImpl();
if (self)
{
ret = self->PostConstruct();
--- a/mmserv/tms/tmsimpl/src/tmsmicsourceimpl.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmsimpl/src/tmsmicsourceimpl.cpp Tue May 25 13:16:00 2010 +0300
@@ -51,7 +51,7 @@
gint TMSMicSourceImpl::Create(TMSSource*& tmssource)
{
gint ret(TMS_RESULT_INSUFFICIENT_MEMORY);
- TMSMicSourceImpl *self = new TMSMicSourceImpl;
+ TMSMicSourceImpl *self = new TMSMicSourceImpl();
TRACE_PRN_FN_ENT;
if (self)
@@ -72,7 +72,6 @@
gpointer /*queuehandler*/)
{
gint ret = TMS_RESULT_SUCCESS;
- //static_cast<TMSMicSourceBodyImpl*>(this->iBody)->SetProxy(aProxy, queuehandler);
return ret;
}
--- a/mmserv/tms/tmsimpl/src/tmsmodemsinkbodyimpl.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmsimpl/src/tmsmodemsinkbodyimpl.cpp Tue May 25 13:16:00 2010 +0300
@@ -33,7 +33,7 @@
gint TMSModemSinkBodyImpl::Create(TMSModemSinkBody*& bodyimpl)
{
gint ret(TMS_RESULT_INSUFFICIENT_MEMORY);
- TMSModemSinkBodyImpl* self = new TMSModemSinkBodyImpl;
+ TMSModemSinkBodyImpl* self = new TMSModemSinkBodyImpl();
if (self)
{
ret = self->PostConstruct();
@@ -64,7 +64,6 @@
gpointer /*queuehandler*/)
{
iProxy = aProxy;
- //static_cast<TMSQueueHandler*>(queuehandler)->AddObserver(*this, TMS_SINK_MODEM);
}
// End of file
--- a/mmserv/tms/tmsimpl/src/tmsmodemsinkimpl.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmsimpl/src/tmsmodemsinkimpl.cpp Tue May 25 13:16:00 2010 +0300
@@ -50,7 +50,7 @@
gint TMSModemSinkImpl::Create(TMSSink*& tmssink)
{
gint ret(TMS_RESULT_INSUFFICIENT_MEMORY);
- TMSModemSinkImpl *self = new TMSModemSinkImpl;
+ TMSModemSinkImpl *self = new TMSModemSinkImpl();
TRACE_PRN_FN_ENT;
if (self)
@@ -71,7 +71,6 @@
gpointer /*queuehandler*/)
{
gint ret = TMS_RESULT_SUCCESS;
- //static_cast<TMSModemSinkBodyImpl*>(this->iBody)->SetProxy(aProxy, queuehandler);
return ret;
}
--- a/mmserv/tms/tmsimpl/src/tmsmodemsourcebodyimpl.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmsimpl/src/tmsmodemsourcebodyimpl.cpp Tue May 25 13:16:00 2010 +0300
@@ -33,7 +33,7 @@
gint TMSModemSourceBodyImpl::Create(TMSModemSourceBody*& bodyimpl)
{
gint ret(TMS_RESULT_INSUFFICIENT_MEMORY);
- TMSModemSourceBodyImpl* self = new TMSModemSourceBodyImpl;
+ TMSModemSourceBodyImpl* self = new TMSModemSourceBodyImpl();
if (self)
{
ret = self->PostConstruct();
@@ -64,7 +64,6 @@
gpointer /*queuehandler*/)
{
iProxy = aProxy;
- //static_cast<TMSQueueHandler*>(queuehandler)->AddObserver(*this, TMS_SOURCE_MODEM);
}
// End of file
--- a/mmserv/tms/tmsimpl/src/tmsmodemsourceimpl.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmsimpl/src/tmsmodemsourceimpl.cpp Tue May 25 13:16:00 2010 +0300
@@ -52,7 +52,7 @@
{
gint ret(TMS_RESULT_INSUFFICIENT_MEMORY);
TRACE_PRN_FN_ENT;
- TMSModemSourceImpl *self = new TMSModemSourceImpl;
+ TMSModemSourceImpl *self = new TMSModemSourceImpl();
if (self)
{
ret = self->PostConstruct();
@@ -71,7 +71,6 @@
gpointer /*queuehandler*/)
{
gint ret = TMS_RESULT_SUCCESS;
- //static_cast<TMSModemSourceBodyImpl*>(this->iBody)->SetProxy(aProxy, queuehandler);
return ret;
}
--- a/mmserv/tms/tmsimpl/src/tmspcmbodyimpl.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmsimpl/src/tmspcmbodyimpl.cpp Tue May 25 13:16:00 2010 +0300
@@ -38,7 +38,7 @@
gint TMSPCMFormatBodyImpl::Create(TMSPCMFormatBody*& bodyimpl)
{
gint ret(TMS_RESULT_INSUFFICIENT_MEMORY);
- TMSPCMFormatBodyImpl* self = new TMSPCMFormatBodyImpl;
+ TMSPCMFormatBodyImpl* self = new TMSPCMFormatBodyImpl();
if (self)
{
ret = self->PostConstruct();
--- a/mmserv/tms/tmsimpl/src/tmspcmimpl.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmsimpl/src/tmspcmimpl.cpp Tue May 25 13:16:00 2010 +0300
@@ -53,7 +53,7 @@
gint TMSPCMFormatImpl::Create(TMSFormat*& tmsformat)
{
gint ret(TMS_RESULT_INSUFFICIENT_MEMORY);
- TMSPCMFormatImpl *self = new TMSPCMFormatImpl;
+ TMSPCMFormatImpl *self = new TMSPCMFormatImpl();
TRACE_PRN_FN_ENT;
if (self)
--- a/mmserv/tms/tmsimpl/src/tmsspeakersinkbodyimpl.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmsimpl/src/tmsspeakersinkbodyimpl.cpp Tue May 25 13:16:00 2010 +0300
@@ -33,7 +33,7 @@
gint TMSSpeakerSinkBodyImpl::Create(TMSSpeakerSinkBody*& bodyimpl)
{
gint ret(TMS_RESULT_INSUFFICIENT_MEMORY);
- TMSSpeakerSinkBodyImpl* self = new TMSSpeakerSinkBodyImpl;
+ TMSSpeakerSinkBodyImpl* self = new TMSSpeakerSinkBodyImpl();
if (self)
{
ret = self->PostConstruct();
@@ -64,7 +64,6 @@
gpointer /*queuehandler*/)
{
iProxy = aProxy;
- //static_cast<TMSQueueHandler*>(queuehandler)->AddObserver(*this, TMS_SINK_SPEAKER);
}
// End of file
--- a/mmserv/tms/tmsimpl/src/tmsspeakersinkimpl.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmsimpl/src/tmsspeakersinkimpl.cpp Tue May 25 13:16:00 2010 +0300
@@ -50,7 +50,7 @@
gint TMSSpeakerSinkImpl::Create(TMSSink*& bodyimpl)
{
gint ret(TMS_RESULT_INSUFFICIENT_MEMORY);
- TMSSpeakerSinkImpl* self = new TMSSpeakerSinkImpl;
+ TMSSpeakerSinkImpl* self = new TMSSpeakerSinkImpl();
if (self)
{
ret = self->PostConstruct();
@@ -68,7 +68,6 @@
gpointer /*queuehandler*/)
{
gint ret = TMS_RESULT_SUCCESS;
- //static_cast<TMSSpeakerSinkBodyImpl*>(this->iBody)->SetProxy(aProxy, queuehandler);
return ret;
}
--- a/mmserv/tms/tmsimpl/src/tmsstreambodyimpl.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmsimpl/src/tmsstreambodyimpl.cpp Tue May 25 13:16:00 2010 +0300
@@ -77,7 +77,7 @@
TMSCallProxy* proxy, TMSStream& parent, TMSStreamBody*& bodyimpl)
{
gint ret(TMS_RESULT_INSUFFICIENT_MEMORY);
- TMSStreamBodyImpl* self = new TMSStreamBodyImpl;
+ TMSStreamBodyImpl* self = new TMSStreamBodyImpl();
if (self)
{
ret = self->PostConstruct(callType, stype, proxy, parent);
--- a/mmserv/tms/tmsimpl/src/tmsstreamimpl.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmsimpl/src/tmsstreamimpl.cpp Tue May 25 13:16:00 2010 +0300
@@ -52,7 +52,7 @@
TMSCallProxy* proxy, TMSStream*& strm)
{
gint ret(TMS_RESULT_INSUFFICIENT_MEMORY);
- TMSStreamImpl *self = new TMSStreamImpl;
+ TMSStreamImpl *self = new TMSStreamImpl();
if (self)
{
--- a/mmserv/tms/tmsimpl/src/tmsvolumeeffectbodyimpl.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmsimpl/src/tmsvolumeeffectbodyimpl.cpp Tue May 25 13:16:00 2010 +0300
@@ -40,7 +40,7 @@
gint TMSVolumeEffectBodyImpl::Create(TMSVolumeEffectBody*& bodyimpl)
{
gint ret(TMS_RESULT_INSUFFICIENT_MEMORY);
- TMSVolumeEffectBodyImpl* self = new TMSVolumeEffectBodyImpl;
+ TMSVolumeEffectBodyImpl* self = new TMSVolumeEffectBodyImpl();
if (self)
{
ret = self->PostConstruct();
--- a/mmserv/tms/tmsimpl/src/tmsvolumeeffectimpl.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmsimpl/src/tmsvolumeeffectimpl.cpp Tue May 25 13:16:00 2010 +0300
@@ -51,7 +51,7 @@
gint TMSVolumeEffectImpl::Create(TMSEffect*& tmseffect)
{
gint ret(TMS_RESULT_INSUFFICIENT_MEMORY);
- TMSVolumeEffectImpl *self = new TMSVolumeEffectImpl;
+ TMSVolumeEffectImpl *self = new TMSVolumeEffectImpl();
TRACE_PRN_FN_ENT;
if (self)
--- a/mmserv/tms/tmsproxy/src/tmsproxy.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmsproxy/src/tmsproxy.cpp Tue May 25 13:16:00 2010 +0300
@@ -31,43 +31,45 @@
// -----------------------------------------------------------------------------
// StartServer
-// Static function to start the server process thread.
-// Start the server process/thread which lives in an EPOCEXE object.
-// Returns: gint: TMS_RESULT_SUCCESS (0) if no error
+//
+// Function that will launch TMS server executable in it its own process.
+// Start the server process/thread, which lives in an EPOCEXE object.
+// Returns: gint: TMS_RESULT_SUCCESS (0) if no error.
// -----------------------------------------------------------------------------
//
-static gint StartServer()
+gint TMSProxy::StartServer()
{
const TUidType serverUid(KNullUid, KNullUid, KTMSServerUid3);
// Only one instance of the server is allowed. Attempt of launching
// second instance of the server will fail with KErrAlreadyExists.
RProcess server;
- gint r = server.Create(KTMSServerName, KNullDesC, serverUid);
+ gint ret = server.Create(KTMSServerFile, KNullDesC, serverUid);
+
+ if (ret == TMS_RESULT_SUCCESS)
+ {
+ TRequestStatus stat;
+ server.Rendezvous(stat);
- if (r != TMS_RESULT_SUCCESS)
- {
- return r;
+ if (stat != KRequestPending)
+ {
+ server.Kill(0); // abort startup
+ }
+ else
+ {
+ server.Resume(); // logon OK - start the server
+ }
+
+ User::WaitForRequest(stat); // wait for start or death
+
+ // We can't use the 'exit reason' if the server panicked, as '0' is a
+ // valid panic 'reason', which cannot be distinguished from
+ // TMS_RESULT_SUCCESS.
+ ret = (server.ExitType() == EExitPanic) ? KErrGeneral : stat.Int();
+ server.Close();
}
- TRequestStatus stat;
- server.Rendezvous(stat);
-
- if (stat != KRequestPending)
- {
- server.Kill(0); // abort startup
- }
- else
- {
- server.Resume(); // logon OK - start the server
- }
-
- User::WaitForRequest(stat); // wait for start or death
-
- // Panic reason cannot be '0' as it would conflict with TMS_RESULT_SUCCESS
- r = (server.ExitType() == EExitPanic) ? KErrGeneral : stat.Int();
- server.Close();
- return r;
+ return ret;
}
// -----------------------------------------------------------------------------
@@ -621,7 +623,7 @@
{
TMSSignalEvent event = {}; //all elements initialized to zeros
event.type = aEventType;
- event.reason = aError;
+ event.reason = TMSRESULT(aError);
event.user_data = NULL; //use only to return data passed in by the user
switch (aEventType)
--- a/mmserv/tms/tmsserver/inc/tmsserver.h Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmsserver/inc/tmsserver.h Tue May 25 13:16:00 2010 +0300
@@ -42,7 +42,7 @@
class TMSServer : public CServer2
{
public:
- static TMSServer* NewL();
+ static void RunServerL();
~TMSServer();
void AddSession();
@@ -79,6 +79,7 @@
void CancelCenRepHandler();
private:
+ static TMSServer* NewLC();
TMSServer();
void ConstructL();
CSession2* NewSessionL(const TVersion& aVersion,
--- a/mmserv/tms/tmsserver/inc/tmsserversession.h Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmsserver/inc/tmsserversession.h Tue May 25 13:16:00 2010 +0300
@@ -15,8 +15,8 @@
*
*/
-#ifndef __TMSSERVERSESSION_H
-#define __TMSSERVERSESSION_H
+#ifndef TMSSERVERSESSION_H
+#define TMSSERVERSESSION_H
// INCLUDES
#include <sounddevice.h>
@@ -79,6 +79,6 @@
} //namespace TMS
-#endif //__TMSSERVERSESSION_H
+#endif //TMSSERVERSESSION_H
// End of file
--- a/mmserv/tms/tmsserver/src/tmsserver.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmsserver/src/tmsserver.cpp Tue May 25 13:16:00 2010 +0300
@@ -42,12 +42,11 @@
//
// -----------------------------------------------------------------------------
//
-TMSServer* TMSServer::NewL()
+TMSServer* TMSServer::NewLC()
{
TMSServer* self = new (ELeave) TMSServer;
CleanupStack::PushL(self);
self->ConstructL();
- CleanupStack::Pop(self);
return self;
}
@@ -860,21 +859,24 @@
}
// -----------------------------------------------------------------------------
-// RunServerL
+// TMSServer::RunServerL
//
// -----------------------------------------------------------------------------
//
-static void RunServerL()
+void TMSServer::RunServerL()
{
TRACE_PRN_N(_L("TMS->RunServerL"));
+ // Naming the server thread after the server helps to debug panics
+ User::LeaveIfError(User::RenameThread(KTMSServerName));
+
// Create and install the active scheduler we need
CActiveScheduler* scheduler = new (ELeave) CActiveScheduler;
CleanupStack::PushL(scheduler);
CActiveScheduler::Install(scheduler);
// Create the server (leave it on the cleanup stack)
- TMSServer* server = TMSServer::NewL();
+ TMSServer* server = TMSServer::NewLC();
// Initialisation complete, now signal the client
RProcess::Rendezvous(TMS_RESULT_SUCCESS);
@@ -884,7 +886,7 @@
// Ready to exit.
// Cleanup scheduler and delete the server
- delete server;
+ CleanupStack::PopAndDestroy(server);
CleanupStack::PopAndDestroy(scheduler);
TRACE_PRN_N(_L("TMS->RunServerL - TMS server closed"));
@@ -1133,7 +1135,7 @@
TInt r = KErrNoMemory;
if (cleanup)
{
- TRAP(r, RunServerL());
+ TRAP(r, TMSServer::RunServerL());
delete cleanup;
}
__UHEAP_MARKEND;
--- a/mmserv/tms/tmsutility/src/tmsutility.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmserv/tms/tmsutility/src/tmsutility.cpp Tue May 25 13:16:00 2010 +0300
@@ -52,7 +52,7 @@
result = TMS_RESULT_INSUFFICIENT_MEMORY;
break;
case KErrNotSupported: //-5
- result = TMS_RESULT_DOES_NOT_EXIST;
+ result = TMS_RESULT_ILLEGAL_OPERATION;
break;
case KErrArgument: //-6
result = TMS_RESULT_INVALID_ARGUMENT;
--- a/mmfenh/advancedaudiocontroller/audiocontrollerpluginsvariant/AdvancedAudioController/Src/AdvancedAudioPlayController.cpp Tue May 11 16:42:02 2010 +0300
+++ b/mmfenh/advancedaudiocontroller/audiocontrollerpluginsvariant/AdvancedAudioController/Src/AdvancedAudioPlayController.cpp Tue May 25 13:16:00 2010 +0300
@@ -1910,7 +1910,7 @@
}
else
{
// This is needed for non-seekable sources as DoRepeat() calls DoInitialize in this case
// this resets the source to read from 0 and sets the iState to EInitializing.
// BufferFilled will not read the header again, change state to EInitialized and seek to the iInitPosition.
// The next BufferFilled will come here, where we will continue playback from byte position 0
@@ -2412,20 +2412,20 @@
DP0(_L("CAdvancedAudioPlayController::LastBufferSent End"));
}
-void CAdvancedAudioPlayController::DoRepeat()
+void CAdvancedAudioPlayController::DoRepeatL()
{
- DP0(_L("CAdvancedAudioPlayController::DoRepeat Begin"));
+ DP0(_L("CAdvancedAudioPlayController::DoRepeatL Begin"));
// save the current position, this will be used to calculate the position in loop play when
// client calls for PositionL() or Pause() operations
// TODO: need to check this position when loop play is going on in a play window
iSavedTimePositionInMicroSecs = iAudioOutput->CalculateAudioOutputPositionL();
- DP1(_L("CAdvancedAudioPlayController::DoRepeat iSavedTimePositionInMicroSecs[%u]"), iSavedTimePositionInMicroSecs);
+ DP1(_L("CAdvancedAudioPlayController::DoRepeatL iSavedTimePositionInMicroSecs[%u]"), iSavedTimePositionInMicroSecs);
if ((!iRepeatForever) && (iCurrentRepeatCount < iRepeatCount))
{
iCurrentRepeatCount++;
}
- DP1(_L("CAdvancedAudioPlayController::DoRepeat Number of times played till now = %d"), iCurrentRepeatCount);
+ DP1(_L("CAdvancedAudioPlayController::DoRepeatL Number of times played till now = %d"), iCurrentRepeatCount);
if (iSourceIsTimeSeekable || iSourceIsPosSeekable)
{ // For seekable source
@@ -2434,25 +2434,25 @@
// SetPlayWindow(iPlayWindowStartPosition, iPlayWindowEndPosition);
if (iPlayWindowStartPosition > 0)
{
- DP1(_L("CAdvancedAudioPlayController::DoRepeat SetPositionL[%d]ms"), I64LOW(iPlayWindowStartPosition.Int64()/1000));
+ DP1(_L("CAdvancedAudioPlayController::DoRepeatL SetPositionL[%d]ms"), I64LOW(iPlayWindowStartPosition.Int64()/1000));
SetPositionL(iPlayWindowStartPosition);
}
else
{
- DP0(_L("CAdvancedAudioPlayController::DoRepeat SetPositionL(0)"));
+ DP0(_L("CAdvancedAudioPlayController::DoRepeatL SetPositionL(0)"));
SetPositionL(0);
}
// Register for PlayWindow end position as the FrameTable has set its playwindowendpostime to zero
if (iPlayWindowEndPosition > 0)
{
- DP1(_L("CAdvancedAudioPlayController::DoRepeat iAudioUtility->SetPlayWindowEndTimeMs(%d)"), I64LOW(iPlayWindowEndPosition.Int64()/1000));
+ DP1(_L("CAdvancedAudioPlayController::DoRepeatL iAudioUtility->SetPlayWindowEndTimeMs(%d)"), I64LOW(iPlayWindowEndPosition.Int64()/1000));
iAudioUtility->SetPlayWindowEndTimeMs(iPlayWindowEndPosition.Int64() / 1000);
}
}
else
{ // For non-seekable source
// Stop and start playback
- DP0(_L("CAdvancedAudioPlayController::DoRepeat Non-Seekable source."));
+ DP0(_L("CAdvancedAudioPlayController::DoRepeatL Non-Seekable source."));
iAudioOutput->StopL(EFalse);
iDataSourceAdapter->SourceStopL(); // clear the buffers in the source before seeking and priming it
DoInitializeL();
@@ -2460,13 +2460,19 @@
// and the current position is adjusted to be placed after the header.
iReadHeader = ETrue;
}
- DP0(_L("CAdvancedAudioPlayController::DoRepeat End") );
+ DP0(_L("CAdvancedAudioPlayController::DoRepeatL End") );
}
EXPORT_C void CAdvancedAudioPlayController::TrailingSilenceTimerComplete()
{
DP0(_L("CAdvancedAudioPlayController::TrailingSilenceTimerComplete "));
- DoRepeat();
+
+ TRAPD(err,DoRepeatL()); //Fix for Bug ECWG-84WE9J
+ DP1(_L("CAdvancedAudioPlayController::TrailingSilenceTimerComplete: DoRepeatL [%d]"), err);
+ if(err)
+ {
+ SendEventToClient(TMMFEvent(KMMFEventCategoryPlaybackComplete,err));
+ }
}
EXPORT_C TInt CAdvancedAudioPlayController::GetCodecConfigData(RArray<TInt>& aCodecConfigData)
@@ -1910,7 +1910,7 @@
else
{
- // This is needed for non-seekable sources as DoRepeat() calls DoInitialize in this case
+ // This is needed for non-seekable sources as DoRepeatL() calls DoInitialize in this case
// this resets the source to read from 0 and sets the iState to EInitializing.
// BufferFilled will not read the header again, change state to EInitialized and seek to the iInitPosition.